@@ -2,6 +2,8 @@
 
 // Start of http v.1.6.6
 
+use JetBrains\PhpStorm\Pure;
+
 class HttpException extends Exception  {
 	public $innerException;
 }
@@ -214,6 +216,7 @@ class HttpMessage implements Countable, Serializable, Iterator {
 	 * @link https://php.net/manual/en/function.httpmessage-getbody.php
 	 * @return string the message body as string.
 	 */
+    #[Pure]
 	public function getBody () {}
 
 	/**
@@ -236,6 +239,7 @@ class HttpMessage implements Countable, Serializable, Iterator {
 	 * </p>
 	 * @return string|null the header value on success or NULL if the header does not exist.
 	 */
+    #[Pure]
 	public function getHeader ($header) {}
 
 	/**
@@ -244,13 +248,14 @@ class HttpMessage implements Countable, Serializable, Iterator {
 	 * @link https://php.net/manual/en/function.httpmessage-getheaders.php
 	 * @return array an associative array containing the messages HTTP headers.
 	 */
+    #[Pure]
 	public function getHeaders () {}
 
 	/**
 	 * (PECL pecl_http &gt;= 0.10.0)<br/>
 	 * Set headers
 	 * @link https://php.net/manual/en/function.httpmessage-setheaders.php
-	 * @param array $headers <p>
+	 * @param array $header <p>
 	 * associative array containing the new HTTP headers, which will replace all previous HTTP headers of the message
 	 * </p>
 	 * @return void
@@ -279,6 +284,7 @@ class HttpMessage implements Countable, Serializable, Iterator {
 	 * @link https://php.net/manual/en/function.httpmessage-gettype.php
 	 * @return int the HttpMessage::TYPE.
 	 */
+    #[Pure]
 	public function getType () {}
 
 	/**
@@ -292,6 +298,7 @@ class HttpMessage implements Countable, Serializable, Iterator {
 	 */
 	public function setType ($type) {}
 
+    #[Pure]
 	public function getInfo () {}
 
 	/**
@@ -305,6 +312,7 @@ class HttpMessage implements Countable, Serializable, Iterator {
 	 * @link https://php.net/manual/en/function.httpmessage-getresponsecode.php
 	 * @return int|false the HTTP response code if the message is of type HttpMessage::TYPE_RESPONSE, else FALSE.
 	 */
+    #[Pure]
 	public function getResponseCode () {}
 
 	/**
@@ -326,6 +334,7 @@ class HttpMessage implements Countable, Serializable, Iterator {
 	 * @return string the HTTP response status string if the message is of type
 	 * HttpMessage::TYPE_RESPONSE, else FALSE.
 	 */
+    #[Pure]
 	public function getResponseStatus () {}
 
 	/**
@@ -347,6 +356,7 @@ class HttpMessage implements Countable, Serializable, Iterator {
 	 * @return string|false the request method name on success, or FALSE if the message is
 	 * not of type HttpMessage::TYPE_REQUEST.
 	 */
+    #[Pure]
 	public function getRequestMethod () {}
 
 	/**
@@ -368,6 +378,7 @@ class HttpMessage implements Countable, Serializable, Iterator {
 	 * @return string|false the request URL as string on success, or FALSE if the message
 	 * is not of type HttpMessage::TYPE_REQUEST.
 	 */
+    #[Pure]
 	public function getRequestUrl () {}
 
 	/**
@@ -388,6 +399,7 @@ class HttpMessage implements Countable, Serializable, Iterator {
 	 * @link https://php.net/manual/en/function.httpmessage-gethttpversion.php
 	 * @return string the HTTP protocol version as string.
 	 */
+    #[Pure]
 	public function getHttpVersion () {}
 
 	/**
@@ -421,6 +433,7 @@ class HttpMessage implements Countable, Serializable, Iterator {
 	 * @link https://php.net/manual/en/function.httpmessage-getparentmessage.php
 	 * @return HttpMessage the parent HttpMessage object.
 	 */
+    #[Pure]
 	public function getParentMessage () {}
 
 	/**
@@ -617,6 +630,7 @@ class HttpQueryString implements Serializable, ArrayAccess {
 	 * </p>
 	 * @return mixed the value of the query string param or the whole query string if no key was specified on success or defval if key does not exist.
 	 */
+    #[Pure]
 	public function get ($key = null, $type = null, $defval = null, $delete = null) {}
 
 	/**
@@ -646,6 +660,7 @@ class HttpQueryString implements Serializable, ArrayAccess {
 	 * @param $defval [optional]
 	 * @param $delete [optional]
 	 */
+    #[Pure]
 	public function getBool ($name, $defval, $delete) {}
 
 	/**
@@ -653,6 +668,7 @@ class HttpQueryString implements Serializable, ArrayAccess {
 	 * @param $defval [optional]
 	 * @param $delete [optional]
 	 */
+    #[Pure]
 	public function getInt ($name, $defval, $delete) {}
 
 	/**
@@ -660,6 +676,7 @@ class HttpQueryString implements Serializable, ArrayAccess {
 	 * @param $defval [optional]
 	 * @param $delete [optional]
 	 */
+    #[Pure]
 	public function getFloat ($name, $defval, $delete) {}
 
 	/**
@@ -667,6 +684,7 @@ class HttpQueryString implements Serializable, ArrayAccess {
 	 * @param $defval [optional]
 	 * @param $delete [optional]
 	 */
+    #[Pure]
 	public function getString ($name, $defval, $delete) {}
 
 	/**
@@ -674,6 +692,7 @@ class HttpQueryString implements Serializable, ArrayAccess {
 	 * @param $defval [optional]
 	 * @param $delete [optional]
 	 */
+    #[Pure]
 	public function getArray ($name, $defval, $delete) {}
 
 	/**
@@ -681,6 +700,7 @@ class HttpQueryString implements Serializable, ArrayAccess {
 	 * @param $defval [optional]
 	 * @param $delete [optional]
 	 */
+    #[Pure]
 	public function getObject ($name, $defval, $delete) {}
 
 	/**
@@ -871,24 +891,24 @@ class HttpRequest  {
 	 * @param int $request_method [optional] <p>
 	 * the request method to use
 	 * </p>
-	 * @param array $options [optional] <p>
+	 * @param null|array $options [optional] <p>
 	 * an associative array with request options
 	 * </p>
 	 */
-	public function __construct ($url = null, $request_method = null, array $options = null ) {}
+	public function __construct ($url = null, $request_method = null, ?array $options = null ) {}
 
 	/**
 	 * (PECL pecl_http &gt;= 0.10.0)<br/>
 	 * Set options
 	 * @link https://php.net/manual/en/function.httprequest-setoptions.php
-	 * @param array $options [optional] <p>
+	 * @param null|array $options [optional] <p>
 	 * an associative array, which values will overwrite the
 	 * currently set request options;
 	 * if empty or omitted, the options of the HttpRequest object will be reset
 	 * </p>
 	 * @return bool true on success or false on failure.
 	 */
-	public function setOptions (array $options = null ) {}
+	public function setOptions (?array $options = null ) {}
 
 	/**
 	 * (PECL pecl_http &gt;= 0.10.0)<br/>
@@ -896,19 +916,20 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getoptions.php
 	 * @return array an associative array containing currently set options.
 	 */
+    #[Pure]
 	public function getOptions () {}
 
 	/**
 	 * (PECL pecl_http &gt;= 0.10.0)<br/>
 	 * Set ssl options
 	 * @link https://php.net/manual/en/function.httprequest-setssloptions.php
-	 * @param array $options [optional] <p>
+	 * @param null|array $options [optional] <p>
 	 * an associative array containing any SSL specific options;
 	 * if empty or omitted, the SSL options will be reset
 	 * </p>
 	 * @return bool true on success or false on failure.
 	 */
-	public function setSslOptions (array $options = null ) {}
+	public function setSslOptions (?array $options = null ) {}
 
 	/**
 	 * (PECL pecl_http &gt;= 0.10.0)<br/>
@@ -916,13 +937,14 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getssloptions.php
 	 * @return array an associative array containing any previously set SSL options.
 	 */
+    #[Pure]
 	public function getSslOptions () {}
 
 	/**
 	 * (PECL pecl_http &gt;= 0.12.0)<br/>
 	 * Add ssl options
 	 * @link https://php.net/manual/en/function.httprequest-addssloptions.php
-	 * @param array $options <p>
+	 * @param array $option <p>
 	 * an associative array as parameter containing additional SSL specific options
 	 * </p>
 	 * @return bool true on success or false on failure.
@@ -946,19 +968,20 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getheaders.php
 	 * @return array an associative array containing all currently set headers.
 	 */
+    #[Pure]
 	public function getHeaders () {}
 
 	/**
 	 * (PECL pecl_http &gt;= 0.12.0)<br/>
 	 * Set headers
 	 * @link https://php.net/manual/en/function.httprequest-setheaders.php
-	 * @param array $headers [optional] <p>
+	 * @param null|array $headers [optional] <p>
 	 * an associative array as parameter containing header name/value pairs;
 	 * if empty or omitted, all previously set headers will be unset
 	 * </p>
 	 * @return bool true on success or false on failure.
 	 */
-	public function setHeaders ( array $headers = null ) {}
+	public function setHeaders ( ?array $headers = null ) {}
 
 	/**
 	 * (PECL pecl_http &gt;= 0.10.0)<br/>
@@ -977,19 +1000,20 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getcookies.php
 	 * @return array an associative array containing any previously set cookies.
 	 */
+    #[Pure]
 	public function getCookies () {}
 
 	/**
 	 * (PECL pecl_http &gt;= 0.12.0)<br/>
 	 * Set cookies
 	 * @link https://php.net/manual/en/function.httprequest-setcookies.php
-	 * @param array $cookies [optional] <p>
+	 * @param null|array $cookies [optional] <p>
 	 * an associative array as parameter containing cookie name/value pairs;
 	 * if empty or omitted, all previously set cookies will be unset
 	 * </p>
 	 * @return bool true on success or false on failure.
 	 */
-	public function setCookies ( array $cookies = null ) {}
+	public function setCookies ( ?array $cookies = null ) {}
 
 	/**
 	 * (PECL pecl_http &gt;= 1.0.0)<br/>
@@ -1029,6 +1053,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getmethod.php
 	 * @return int the currently set request method.
 	 */
+    #[Pure]
 	public function getMethod () {}
 
 	/**
@@ -1048,6 +1073,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-geturl.php
 	 * @return string the currently set request url as string.
 	 */
+    #[Pure]
 	public function getUrl () {}
 
 	/**
@@ -1068,6 +1094,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getcontenttype.php
 	 * @return string the previously set content type as string.
 	 */
+    #[Pure]
 	public function getContentType () {}
 
 	/**
@@ -1089,6 +1116,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getquerydata.php
 	 * @return string a string containing the urlencoded query.
 	 */
+    #[Pure]
 	public function getQueryData () {}
 
 	/**
@@ -1120,6 +1148,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getpostfields.php
 	 * @return array the currently set post fields as associative array.
 	 */
+    #[Pure]
 	public function getPostFields () {}
 
 	/**
@@ -1138,6 +1167,7 @@ class HttpRequest  {
 	 */
 	public function setBody ($request_body_data) {}
 
+    #[Pure]
 	public function getBody () {}
 
 	/**
@@ -1162,6 +1192,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getrawpostdata.php
 	 * @return string a string containing the currently set raw post data.
 	 */
+    #[Pure]
 	public function getRawPostData () {}
 
 	/**
@@ -1211,6 +1242,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getpostfiles.php
 	 * @return array an array containing currently set post files.
 	 */
+    #[Pure]
 	public function getPostFiles () {}
 
 	/**
@@ -1231,6 +1263,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getputfile.php
 	 * @return string a string containing the path to the currently set put file.
 	 */
+    #[Pure]
 	public function getPutFile () {}
 
 	/**
@@ -1250,6 +1283,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getputdata.php
 	 * @return string a string containing the currently set PUT data.
 	 */
+    #[Pure]
 	public function getPutData () {}
 
 	/**
@@ -1279,6 +1313,7 @@ class HttpRequest  {
 	 * array holding all response headers, as well as the key "body" containing a
 	 * string with the response body.
 	 */
+    #[Pure]
 	public function getResponseData () {}
 
 	/**
@@ -1291,6 +1326,7 @@ class HttpRequest  {
 	 * @return mixed either a string with the value of the header matching name if requested,
 	 * FALSE on failure, or an associative array containing all response headers.
 	 */
+    #[Pure]
 	public function getResponseHeader ($name = null) {}
 
 	/**
@@ -1300,12 +1336,13 @@ class HttpRequest  {
 	 * @param int $flags [optional] <p>
 	 * http_parse_cookie flags
 	 * </p>
-	 * @param array $allowed_extras [optional] <p>
+	 * @param null|array $allowed_extras [optional] <p>
 	 * allowed keys treated as extra information instead of cookie names
 	 * </p>
 	 * @return stdClass[] an array of stdClass objects like http_parse_cookie would return.
 	 */
-	public function getResponseCookies ($flags = null,  array $allowed_extras = null ) {}
+    #[Pure]
+	public function getResponseCookies ($flags = null,  ?array $allowed_extras = null ) {}
 
 	/**
 	 * (PECL pecl_http &gt;= 0.10.0)<br/>
@@ -1313,6 +1350,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getresponsecode.php
 	 * @return int an int representing the response code.
 	 */
+    #[Pure]
 	public function getResponseCode () {}
 
 	/**
@@ -1321,6 +1359,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getresponsestatus.php
 	 * @return string a string containing the response status text.
 	 */
+    #[Pure]
 	public function getResponseStatus () {}
 
 	/**
@@ -1329,6 +1368,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getresponsebody.php
 	 * @return string a string containing the response body.
 	 */
+    #[Pure]
 	public function getResponseBody () {}
 
 	/**
@@ -1343,6 +1383,7 @@ class HttpRequest  {
 	 * requested, FALSE on failure, or an associative array containing all
 	 * available info.
 	 */
+    #[Pure]
 	public function getResponseInfo ($name = null) {}
 
 	/**
@@ -1351,6 +1392,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getresponsemessage.php
 	 * @return HttpMessage an HttpMessage object of the response.
 	 */
+    #[Pure]
 	public function getResponseMessage () {}
 
 	/**
@@ -1359,6 +1401,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getrawresponsemessage.php
 	 * @return string the complete web server response, including the headers in a form of a string.
 	 */
+    #[Pure]
 	public function getRawResponseMessage () {}
 
 	/**
@@ -1367,6 +1410,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getrequestmessage.php
 	 * @return HttpMessage an HttpMessage object representing the sent request.
 	 */
+    #[Pure]
 	public function getRequestMessage () {}
 
 	/**
@@ -1375,6 +1419,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-getrawrequestmessage.php
 	 * @return string an HttpMessage in a form of a string.
 	 */
+    #[Pure]
 	public function getRawRequestMessage () {}
 
 	/**
@@ -1383,6 +1428,7 @@ class HttpRequest  {
 	 * @link https://php.net/manual/en/function.httprequest-gethistory.php
 	 * @return HttpMessage an HttpMessage object representing the complete request/response history.
 	 */
+    #[Pure]
 	public function getHistory () {}
 
 	/**
@@ -1529,11 +1575,11 @@ class HttpRequestPool implements Countable, Iterator {
 	 * (PECL pecl_http &gt;= 0.10.0)<br/>
 	 * HttpRequestPool constructor
 	 * @link https://php.net/manual/en/function.httprequestpool-construct.php
-	 * @param HttpRequest $request [optional] <p>
+	 * @param null|HttpRequest $request [optional] <p>
 	 * HttpRequest object to attach
 	 * </p>
 	 */
-	public function __construct ( HttpRequest $request = null) {}
+	public function __construct ( ?HttpRequest $request = null) {}
 
 	/**
 	 * (PECL pecl_http &gt;= 0.10.0)<br/>
@@ -1615,6 +1661,7 @@ class HttpRequestPool implements Countable, Iterator {
 	 * @link https://php.net/manual/en/function.httprequestpool-getattachedrequests.php
 	 * @return array an array containing all currently attached HttpRequest objects.
 	 */
+    #[Pure]
 	public function getAttachedRequests () {}
 
 	/**
@@ -1623,6 +1670,7 @@ class HttpRequestPool implements Countable, Iterator {
 	 * @link https://php.net/manual/en/function.httprequestpool-getfinishedrequests.php
 	 * @return array an array containing all attached HttpRequest objects that already have finished their work.
 	 */
+    #[Pure]
 	public function getFinishedRequests () {}
 
 	/**
@@ -1972,13 +2020,13 @@ class HttpResponse  {
 	 * (PECL pecl_http &gt;= 0.10.0)<br/>
 	 * Redirect
 	 * @link https://php.net/manual/en/function.httpresponse-redirect.php
-	 * @param string $url [optional]
-	 * @param array $params [optional]
-	 * @param bool $session [optional]
-	 * @param int $status [optional]
+	 * @param null|string $url [optional]
+	 * @param null|array $params [optional]
+	 * @param null|bool $session [optional]
+	 * @param null|int $status [optional]
 	 * @return void
 	 */
-	public static function redirect ($url = null,  array $params = null , $session = null, $status = null) {}
+	public static function redirect ($url = null,  ?array $params = null , $session = null, $status = null) {}
 
 	/**
 	 * (PECL pecl_http &gt;= 0.12.0)<br/>
@@ -2132,6 +2180,7 @@ class HttpUtil  {
  * </p>
  * @return string the HTTP date as string.
  */
+#[Pure]
 function http_date ($timestamp = null) {}
 
 /**
@@ -2144,16 +2193,16 @@ function http_date ($timestamp = null) {}
  * @param mixed $parts [optional] <p>
  * same as the first argument
  * </p>
- * @param int $flags [optional] <p>
+ * @param null|int $flags [optional] <p>
  * a bitmask of binary or'ed HTTP_URL constants;
  * HTTP_URL_REPLACE is the default
  * </p>
- * @param array &$new_url [optional] <p>
+ * @param null|array &$new_url [optional] <p>
  * if set, it will be filled with the parts of the composed url like parse_url would return
  * </p>
  * @return string|false the new URL as string on success or false on failure.
  */
-function http_build_url ($url = null, $parts = null, $flags = null,  array &$new_url = null ) {}
+function http_build_url ($url = null, $parts = null, $flags = null,  ?array &$new_url = null ) {}
 
 /**
  * (PECL pecl_http &gt;= 0.23.0)<br/>
@@ -2170,6 +2219,7 @@ function http_build_url ($url = null, $parts = null, $flags = null,  array &$new
  * </p>
  * @return string|false the built query as string on success or false on failure.
  */
+#[Pure]
 function http_build_str (array $query, $prefix = null, $arg_separator = null) {}
 
 /**
@@ -2179,12 +2229,12 @@ function http_build_str (array $query, $prefix = null, $arg_separator = null) {}
  * @param array $supported <p>
  * array containing the supported languages as values
  * </p>
- * @param array &$result [optional] <p>
+ * @param null|array &$result [optional] <p>
  * will be filled with an array containing the negotiation results
  * </p>
  * @return string the negotiated language or the default language (i.e. first array entry) if none match.
  */
-function http_negotiate_language (array $supported,  array &$result = null ) {}
+function http_negotiate_language (array $supported, ?array &$result = null ) {}
 
 /**
  * (PECL pecl_http &gt;= 0.1.0)<br/>
@@ -2193,12 +2243,12 @@ function http_negotiate_language (array $supported,  array &$result = null ) {}
  * @param array $supported <p>
  * array containing the supported charsets as values
  * </p>
- * @param array &$result [optional] <p>
+ * @param null|array &$result [optional] <p>
  * will be filled with an array containing the negotiation results
  * </p>
  * @return string the negotiated charset or the default charset (i.e. first array entry) if none match.
  */
-function http_negotiate_charset (array $supported,  array &$result = null ) {}
+function http_negotiate_charset (array $supported, ?array &$result = null ) {}
 
 /**
  * (PECL pecl_http &gt;= 0.19.0)<br/>
@@ -2207,12 +2257,12 @@ function http_negotiate_charset (array $supported,  array &$result = null ) {}
  * @param array $supported <p>
  * array containing the supported content types as values
  * </p>
- * @param array &$result [optional] <p>
+ * @param null|array &$result [optional] <p>
  * will be filled with an array containing the negotiation results
  * </p>
  * @return string the negotiated content type or the default content type (i.e. first array entry) if none match.
  */
-function http_negotiate_content_type (array $supported,  array &$result = null ) {}
+function http_negotiate_content_type (array $supported, ?array &$result = null ) {}
 
 /**
  * (PECL pecl_http &gt;= 0.1.0)<br/>
@@ -2221,18 +2271,18 @@ function http_negotiate_content_type (array $supported,  array &$result = null )
  * @param string $url [optional] <p>
  * the URL to redirect to
  * </p>
- * @param array $params [optional] <p>
+ * @param null|array $params [optional] <p>
  * associative array of query parameters
  * </p>
- * @param bool $session [optional] <p>
+ * @param null|bool $session [optional] <p>
  * whether to append session information
  * </p>
- * @param int $status [optional] <p>
+ * @param null|int $status [optional] <p>
  * custom response status code
  * </p>
  * @return void|false returns false or exits with the specified redirection status code
  */
-function http_redirect ($url = null,  array $params = null , $session = null, $status = null) {}
+function http_redirect ($url = null, ?array $params = null , $session = null, $status = null) {}
 
 /**
  * (PECL pecl_http &gt;= 0.10.0)<br/>
@@ -2309,6 +2359,7 @@ function http_send_content_disposition ($filename, $inline = null) {}
  * </p>
  * @return bool true if timestamp represents an earlier date than the header, else false.
  */
+#[Pure]
 function http_match_modified ($timestamp = null, $for_range = null) {}
 
 /**
@@ -2323,6 +2374,7 @@ function http_match_modified ($timestamp = null, $for_range = null) {}
  * </p>
  * @return bool true if ETag matches or the header contained the asterisk (&quot;*&quot;), else false.
  */
+#[Pure]
 function http_match_etag ($etag, $for_range = null) {}
 
 /**
@@ -2335,6 +2387,7 @@ function http_match_etag ($etag, $for_range = null) {}
  * @return bool with 304 Not Modified if the entity is cached.
  * &see.http.configuration.force_exit;
  */
+#[Pure]
 function http_cache_last_modified ($timestamp_or_expires = null) {}
 
 /**
@@ -2347,6 +2400,7 @@ function http_cache_last_modified ($timestamp_or_expires = null) {}
  * @return bool with 304 Not Modified if the entity is cached.
  * &see.http.configuration.force_exit;
  */
+#[Pure]
 function http_cache_etag ($etag = null) {}
 
 /**
@@ -2391,6 +2445,7 @@ function http_send_stream ($stream) {}
  * </p>
  * @return string|false the decoded string on success or false on failure.
  */
+#[Pure]
 function http_chunked_decode ($encoded) {}
 
 /**
@@ -2402,6 +2457,7 @@ function http_chunked_decode ($encoded) {}
  * </p>
  * @return object a hierarchical object structure of the parsed messages.
  */
+#[Pure]
 function http_parse_message ($message) {}
 
 /**
@@ -2413,6 +2469,7 @@ function http_parse_message ($message) {}
  * </p>
  * @return array|false an array on success or false on failure.
  */
+#[Pure]
 function http_parse_headers ($header) {}
 
 /**
@@ -2425,13 +2482,14 @@ function http_parse_headers ($header) {}
  * @param int $flags [optional] <p>
  * parse flags (HTTP_COOKIE_PARSE_RAW)
  * </p>
- * @param array $allowed_extras [optional] <p>
+ * @param null|array $allowed_extras [optional] <p>
  * array containing recognized extra keys;
  * by default all unknown keys will be treated as cookie names
  * </p>
  * @return stdClass|false a stdClass object on success or false on failure.
  */
-function http_parse_cookie ($cookie, $flags = null,  array $allowed_extras = null ) {}
+#[Pure]
+function http_parse_cookie ($cookie, $flags = null, ?array $allowed_extras = null ) {}
 
 /**
  * (PECL pecl_http &gt;= 1.2.0)<br/>
@@ -2442,6 +2500,7 @@ function http_parse_cookie ($cookie, $flags = null,  array $allowed_extras = nul
  * </p>
  * @return string the cookie(s) as string.
  */
+#[Pure]
 function http_build_cookie (array $cookie) {}
 
 /**
@@ -2456,6 +2515,7 @@ function http_build_cookie (array $cookie) {}
  * </p>
  * @return stdClass parameter list as stdClass object.
  */
+#[Pure]
 function http_parse_params ($param, $flags = null) {}
 
 /**
@@ -2464,6 +2524,7 @@ function http_parse_params ($param, $flags = null) {}
  * @link https://php.net/manual/en/function.http-get-request-headers.php
  * @return array an associative array of incoming request headers.
  */
+#[Pure]
 function http_get_request_headers () {}
 
 /**
@@ -2472,6 +2533,7 @@ function http_get_request_headers () {}
  * @link https://php.net/manual/en/function.http-get-request-body.php
  * @return string|null the raw request body as string on success or NULL on failure.
  */
+#[Pure]
 function http_get_request_body () {}
 
 /**
@@ -2480,6 +2542,7 @@ function http_get_request_body () {}
  * @link https://php.net/manual/en/function.http-get-request-body-stream.php
  * @return resource|null the raw request body as stream on success or NULL on failure.
  */
+#[Pure]
 function http_get_request_body_stream () {}
 
 /**
@@ -2497,6 +2560,7 @@ function http_get_request_body_stream () {}
  * </p>
  * @return bool true if header value matches, else false.
  */
+#[Pure]
 function http_match_request_header ($header, $value, $match_case = null) {}
 
 /**
@@ -2534,15 +2598,14 @@ function http_persistent_handles_ident ($ident) {}
  * @param string $url <p>
  * URL
  * </p>
- * @param array $options [optional] <p>
- * &link.http.request.options;
+ * @param null|array $options [optional] <p>
  * </p>
- * @param array &$info [optional] <p>
+ * @param null|array &$info [optional] <p>
  * Will be filled with request/response information
  * </p>
  * @return string
  */
-function http_get ($url, array $options = null ,  array &$info = null ) {}
+function http_get ($url, ?array $options = null, ?array &$info = null) {}
 
 /**
  * (PECL pecl_http &gt;= 0.1.0)<br/>
@@ -2551,15 +2614,13 @@ function http_get ($url, array $options = null ,  array &$info = null ) {}
  * @param string $url [optional] <p>
  * URL
  * </p>
- * @param array $options [optional] <p>
- * &link.http.request.options;
+ * @param null|array $options [optional] <p>
  * </p>
- * @param array &$info [optional] <p>
- * &link.http.request.info;
+ * @param null|array &$info [optional] <p>
  * </p>
  * @return string
  */
-function http_head ($url = null, array $options = null ,  array &$info = null ) {}
+function http_head ($url = null, ?array $options = null, ?array &$info = null) {}
 
 /**
  * (PECL pecl_http &gt;= 0.1.0)<br/>
@@ -2571,15 +2632,13 @@ function http_head ($url = null, array $options = null ,  array &$info = null )
  * @param string $data [optional] <p>
  * String containing the pre-encoded post data
  * </p>
- * @param array $options [optional] <p>
- * &link.http.request.options;
+ * @param null|array $options [optional] <p>
  * </p>
- * @param array &$info [optional] <p>
- * &link.http.request.info;
+ * @param null|array &$info [optional] <p>
  * </p>
  * @return string
  */
-function http_post_data ($url, $data = null, array $options = null ,  array &$info = null ) {}
+function http_post_data ($url, $data = null, ?array $options = null, ?array &$info = null) {}
 
 /**
  * (PECL pecl_http &gt;= 0.10.0)<br/>
@@ -2588,21 +2647,19 @@ function http_post_data ($url, $data = null, array $options = null ,  array &$in
  * @param string $url <p>
  * URL
  * </p>
- * @param array $data [optional] <p>
+ * @param null|array $data [optional] <p>
  * Associative array of POST values
  * </p>
- * @param array $files [optional] <p>
+ * @param null|array $files [optional] <p>
  * Array of files to post
  * </p>
- * @param array $options [optional] <p>
- * &link.http.request.options;
+ * @param null|array $options [optional] <p>
  * </p>
- * @param array &$info [optional] <p>
- * &link.http.request.info;
+ * @param null|array &$info [optional] <p>
  * </p>
  * @return string
  */
-function http_post_fields ($url,  array $data = null ,  array $files = null , array $options = null ,  array &$info = null ) {}
+function http_post_fields ($url, ?array $data = null, ?array $files = null, ?array $options = null , ?array &$info = null) {}
 
 /**
  * (PECL pecl_http &gt;= 0.25.0)<br/>
@@ -2611,18 +2668,16 @@ function http_post_fields ($url,  array $data = null ,  array $files = null , ar
  * @param string $url <p>
  * URL
  * </p>
- * @param string $data [optional] <p>
+ * @param null|string $data [optional] <p>
  * PUT request body
  * </p>
- * @param array $options [optional] <p>
- * &link.http.request.options;
+ * @param null|array $options [optional] <p>
  * </p>
- * @param array &$info [optional] <p>
- * &link.http.request.info;
+ * @param null|array &$info [optional] <p>
  * </p>
  * @return string
  */
-function http_put_data ($url, $data = null, array $options = null ,  array &$info = null ) {}
+function http_put_data ($url, $data = null, ?array $options = null, ?array &$info = null) {}
 
 /**
  * (PECL pecl_http &gt;= 0.10.0)<br/>
@@ -2631,18 +2686,16 @@ function http_put_data ($url, $data = null, array $options = null ,  array &$inf
  * @param string $url <p>
  * URL
  * </p>
- * @param string $file [optional] <p>
+ * @param null|string $file [optional] <p>
  * The file to put
  * </p>
- * @param array $options [optional] <p>
- * &link.http.request.options;
+ * @param null|array $options [optional] <p>
  * </p>
- * @param array &$info [optional] <p>
- * &link.http.request.info;
+ * @param null|array &$info [optional] <p>
  * </p>
  * @return string
  */
-function http_put_file ($url, $file = null, array $options = null ,  array &$info = null ) {}
+function http_put_file ($url, $file = null, ?array $options = null, ?array &$info = null) {}
 
 /**
  * (PECL pecl_http &gt;= 0.10.0)<br/>
@@ -2651,18 +2704,16 @@ function http_put_file ($url, $file = null, array $options = null ,  array &$inf
  * @param string $url <p>
  * URL
  * </p>
- * @param resource $stream [optional] <p>
+ * @param null|resource $stream [optional] <p>
  * The stream to read the PUT request body from
  * </p>
- * @param array $options [optional] <p>
- * &link.http.request.options;
+ * @param null|array $options [optional] <p>
  * </p>
- * @param array &$info [optional] <p>
- * &link.http.request.info;
+ * @param null|array &$info [optional] <p>
  * </p>
  * @return string
  */
-function http_put_stream ($url, $stream = null, array $options = null ,  array &$info = null ) {}
+function http_put_stream ($url, $stream = null, ?array $options = null, ?array &$info = null) {}
 
 /**
  * (PECL pecl_http &gt;= 1.0.0)<br/>
@@ -2671,21 +2722,19 @@ function http_put_stream ($url, $stream = null, array $options = null ,  array &
  * @param int $method <p>
  * Request method
  * </p>
- * @param string $url [optional] <p>
+ * @param null|string $url [optional] <p>
  * URL
  * </p>
- * @param string $body [optional] <p>
+ * @param null|string $body [optional] <p>
  * Request body
  * </p>
- * @param array $options [optional] <p>
- * &link.http.request.options;
+ * @param null|array $options [optional] <p>
  * </p>
- * @param array &$info [optional] <p>
- * &link.http.request.info;
+ * @param null|array &$info [optional] <p>
  * </p>
  * @return string
  */
-function http_request ($method, $url = null, $body = null, array $options = null ,  array &$info = null ) {}
+function http_request ($method, $url = null, $body = null, ?array $options = null, ?array &$info = null) {}
 
 /**
  * (PECL pecl_http &gt;= 1.0.0)<br/>
@@ -2699,6 +2748,7 @@ function http_request ($method, $url = null, $body = null, array $options = null
  * </p>
  * @return string|false encoded string on success or false on failure.
  */
+#[Pure]
 function http_request_body_encode (array $fields, array $files) {}
 
 /**
@@ -2732,6 +2782,7 @@ function http_request_method_unregister ($method) {}
  * </p>
  * @return bool true if the request method is known, else false.
  */
+#[Pure]
 function http_request_method_exists ($method) {}
 
 /**
@@ -2743,6 +2794,7 @@ function http_request_method_exists ($method) {}
  * </p>
  * @return string|false the request method name as string on success or false on failure.
  */
+#[Pure]
 function http_request_method_name ($method) {}
 
 /**
@@ -2753,6 +2805,7 @@ function http_request_method_name ($method) {}
  * @param int $mode
  * @return string
  */
+#[Pure]
 function ob_etaghandler ($data, $mode) {}
 
 /**
@@ -2767,6 +2820,7 @@ function ob_etaghandler ($data, $mode) {}
  * </p>
  * @return string|null the encoded string on success, or NULL on failure.
  */
+#[Pure]
 function http_deflate ($data, $flags = null) {}
 
 /**
@@ -2778,6 +2832,7 @@ function http_deflate ($data, $flags = null) {}
  * </p>
  * @return string|null the decoded string on success, or NULL on failure.
  */
+#[Pure]
 function http_inflate ($data) {}
 
 /**
@@ -2810,6 +2865,7 @@ function ob_inflatehandler ($data, $mode) {}
  * @return int integer, whether requested feature is supported,
  * or a bitmask with all supported features if feature was omitted.
  */
+#[Pure]
 function http_support ($feature = null) {}
 
 
