@@ -1,11 +1,11 @@
 <?php
 
 // Start of mcrypt v.
+use JetBrains\PhpStorm\Deprecated;
 
 /**
- * Deprecated: Encrypt/decrypt data in ECB mode
+ * Encrypt/decrypt data in ECB mode
  * @link https://php.net/manual/en/function.mcrypt-ecb.php
- * @deprecated 5.5 https://secure.php.net/manual/en/migration55.deprecated.php
  * @param string|int $cipher
  * @param string $key
  * @param string $data
@@ -13,12 +13,12 @@
  * @return string
  * @removed 7.0
  */
+#[Deprecated(since: "5.5")]
 function mcrypt_ecb ($cipher, $key, $data, $mode) {}
 
 /**
  * Encrypt/decrypt data in CBC mode
  * @link https://php.net/manual/en/function.mcrypt-cbc.php
- * @deprecated 5.5 https://secure.php.net/manual/en/migration55.deprecated.php
  * @param int|string $cipher
  * @param string $key
  * @param string $data
@@ -27,12 +27,12 @@ function mcrypt_ecb ($cipher, $key, $data, $mode) {}
  * @return string
  * @removed 7.0
  */
+#[Deprecated(since: "5.5")]
 function mcrypt_cbc ($cipher, $key, $data, $mode, $iv = null) {}
 
 /**
  * Encrypt/decrypt data in CFB mode
  * @link https://php.net/manual/en/function.mcrypt-cfb.php
- * @deprecated 5.5 https://secure.php.net/manual/en/migration55.deprecated.php
  * @param int|string $cipher
  * @param string $key
  * @param string $data
@@ -41,12 +41,12 @@ function mcrypt_cbc ($cipher, $key, $data, $mode, $iv = null) {}
  * @return string
  * @removed 7.0
  */
+#[Deprecated(since: '5.5')]
 function mcrypt_cfb ($cipher, $key, $data, $mode, $iv = null) {}
 
 /**
  * Encrypt/decrypt data in OFB mode
  * @link https://php.net/manual/en/function.mcrypt-ofb.php
- * @deprecated 5.5 https://secure.php.net/manual/en/migration55.deprecated.php
  * @param int|string $cipher
  * @param string $key
  * @param string $data
@@ -55,6 +55,7 @@ function mcrypt_cfb ($cipher, $key, $data, $mode, $iv = null) {}
  * @return string
  * @removed 7.0
  */
+#[Deprecated(since: '5.5')]
 function mcrypt_ofb ($cipher, $key, $data, $mode, $iv = null) {}
 
 /**
@@ -63,8 +64,8 @@ function mcrypt_ofb ($cipher, $key, $data, $mode, $iv = null) {}
  * @param int|string $cipher
  * @param string $mode
  * @return int
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_get_key_size ($cipher, $mode) {}
 
 /**
@@ -77,8 +78,8 @@ function mcrypt_get_key_size ($cipher, $mode) {}
  * @param string $mode <p>
  * One of the <b>MCRYPT_MODE_modename</b> constants, or one of the following strings: "ecb", "cbc", "cfb", "ofb", "nofb" or "stream".</p>
  * @return int Gets the block size, as an integer.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_get_block_size ($cipher, $mode) {}
 
 /**
@@ -90,12 +91,12 @@ function mcrypt_get_block_size ($cipher, $mode) {}
  * </p>
  * @return string|false This function returns the name of the cipher or false, if the cipher does
  * not exist.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_get_cipher_name ($cipher) {}
 
 /**
- * Create an initialization vector (IV) from a random source
+ * Creates an initialization vector (IV) from a random source
  * @link https://php.net/manual/en/function.mcrypt-create-iv.php
  * @param int $size <p>
  * Determines the size of the IV, parameter source
@@ -119,34 +120,34 @@ function mcrypt_get_cipher_name ($cipher) {}
  * rand is.
  * </p>
  * @return string|false the initialization vector, or false on error.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_create_iv ($size, $source = MCRYPT_DEV_URANDOM) {}
 
 /**
- * Get an array of all supported ciphers
+ * Gets an array of all supported ciphers
  * @link https://php.net/manual/en/function.mcrypt-list-algorithms.php
  * @param string $lib_dir [optional] <p>
  * Specifies the directory where all algorithms are located. If not
- * specifies, the value of the mcrypt.algorithms_dir &php.ini; directive
+ * specifies, the value of the mcrypt.algorithms_dir (php.ini) directive
  * is used.
  * </p>
  * @return array an array with all the supported algorithms.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_list_algorithms ($lib_dir = null) {}
 
 /**
- * Get an array of all supported modes
+ * Gets an array of all supported modes
  * @link https://php.net/manual/en/function.mcrypt-list-modes.php
  * @param string $lib_dir [optional] <p>
  * Specifies the directory where all modes are located. If not
  * specifies, the value of the mcrypt.modes_dir
- * &php.ini; directive is used.
+ * (php.ini) directive is used.
  * </p>
  * @return array an array with all the supported modes.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_list_modes ($lib_dir = null) {}
 
 /**
@@ -166,8 +167,8 @@ function mcrypt_list_modes ($lib_dir = null) {}
  * @return int|false the size of the Initialisation Vector (IV) in bytes. On error the
  * function returns false. If the IV is ignored in the specified cipher/mode
  * combination zero is returned.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_get_iv_size ($cipher, $mode) {}
 
 /**
@@ -207,8 +208,8 @@ function mcrypt_get_iv_size ($cipher, $mode) {}
  * IV with all bytes set to '\0'.
  * </p>
  * @return string the encrypted data, as a string.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_encrypt ($cipher, $key, $data, $mode, $iv = null) {}
 
 /**
@@ -240,8 +241,8 @@ function mcrypt_encrypt ($cipher, $key, $data, $mode, $iv = null) {}
  * '\0'.
  * </p>
  * @return string the decrypted data as a string.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_decrypt ($cipher, $key, $data, $mode, $iv = null) {}
 
 /**
@@ -267,8 +268,8 @@ function mcrypt_decrypt ($cipher, $key, $data, $mode, $iv = null) {}
  * @param string $mode_directory <p>
  * </p>
  * @return resource|false Normally it returns an encryption descriptor, or false on error.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_module_open ($algorithm, $algorithm_directory, $mode, $mode_directory) {}
 
 /**
@@ -296,8 +297,8 @@ function mcrypt_module_open ($algorithm, $algorithm_directory, $mode, $mode_dire
  * other return value is an unknown error. If an error occurs a warning will
  * be displayed accordingly. false is returned if incorrect parameters
  * were passed.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_generic_init ($td, $key, $iv) {}
 
 /**
@@ -317,12 +318,12 @@ function mcrypt_generic_init ($td, $key, $iv) {}
  * The data to encrypt.
  * </p>
  * @return string the encrypted data.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_generic ($td, $data) {}
 
 /**
- * Decrypt data
+ * Decrypts data
  * @link https://php.net/manual/en/function.mdecrypt-generic.php
  * @param resource $td <p>
  * An encryption descriptor returned by
@@ -332,8 +333,8 @@ function mcrypt_generic ($td, $data) {}
  * Encrypted data.
  * </p>
  * @return string
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mdecrypt_generic ($td, $data) {}
 
 /**
@@ -341,9 +342,9 @@ function mdecrypt_generic ($td, $data) {}
  * @link https://php.net/manual/en/function.mcrypt-generic-end.php
  * @param resource $td
  * @return bool
- * @deprecated 5.4 This function has been DEPRECATED as of PHP 5.4.0.
  * @removed 7.0
  */
+#[Deprecated(since: '5.4')]
 function mcrypt_generic_end ($td) {}
 
 /**
@@ -353,8 +354,8 @@ function mcrypt_generic_end ($td) {}
  * The encryption descriptor.
  * </p>
  * @return bool true on success or false on failure.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_generic_deinit ($td) {}
 
 /**
@@ -364,8 +365,8 @@ function mcrypt_generic_deinit ($td) {}
  * The encryption descriptor.
  * </p>
  * @return int Returns 0 on success and a negative integer on failure
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_enc_self_test ($td) {}
 
 /**
@@ -376,8 +377,8 @@ function mcrypt_enc_self_test ($td) {}
  * </p>
  * @return bool true if the mode is for use with block algorithms, otherwise it
  * returns false.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_enc_is_block_algorithm_mode ($td) {}
 
 /**
@@ -388,8 +389,8 @@ function mcrypt_enc_is_block_algorithm_mode ($td) {}
  * </p>
  * @return bool true if the algorithm is a block algorithm or false if it is
  * a stream one.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_enc_is_block_algorithm ($td) {}
 
 /**
@@ -399,8 +400,8 @@ function mcrypt_enc_is_block_algorithm ($td) {}
  * The encryption descriptor.
  * </p>
  * @return bool true if the mode outputs blocks of bytes or false if it outputs bytes.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_enc_is_block_mode ($td) {}
 
 /**
@@ -410,8 +411,8 @@ function mcrypt_enc_is_block_mode ($td) {}
  * The encryption descriptor.
  * </p>
  * @return int the block size of the specified algorithm in bytes.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_enc_get_block_size ($td) {}
 
 /**
@@ -421,8 +422,8 @@ function mcrypt_enc_get_block_size ($td) {}
  * The encryption descriptor.
  * </p>
  * @return int the maximum supported key size of the algorithm in bytes.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_enc_get_key_size ($td) {}
 
 /**
@@ -436,8 +437,8 @@ function mcrypt_enc_get_key_size ($td) {}
  * array then all key sizes between 1 and
  * mcrypt_enc_get_key_size are supported by the
  * algorithm.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_enc_get_supported_key_sizes ($td) {}
 
 /**
@@ -447,8 +448,8 @@ function mcrypt_enc_get_supported_key_sizes ($td) {}
  * The encryption descriptor.
  * </p>
  * @return int the size of the IV, or 0 if the IV is ignored in the algorithm.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_enc_get_iv_size ($td) {}
 
 /**
@@ -458,8 +459,8 @@ function mcrypt_enc_get_iv_size ($td) {}
  * The encryption descriptor.
  * </p>
  * @return string the name of the opened algorithm as a string.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_enc_get_algorithms_name ($td) {}
 
 /**
@@ -469,8 +470,8 @@ function mcrypt_enc_get_algorithms_name ($td) {}
  * The encryption descriptor.
  * </p>
  * @return string the name as a string.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_enc_get_modes_name ($td) {}
 
 /**
@@ -485,8 +486,8 @@ function mcrypt_enc_get_modes_name ($td) {}
  * </p>
  * @return bool The function returns true if the self test succeeds, or false when if
  * fails.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_module_self_test ($algorithm, $lib_dir = null) {}
 
 /**
@@ -502,8 +503,8 @@ function mcrypt_module_self_test ($algorithm, $lib_dir = null) {}
  * @return bool This function returns true if the mode is for use with block
  * algorithms, otherwise it returns false. (e.g. false for stream, and
  * true for cbc, cfb, ofb).
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_module_is_block_algorithm_mode ($mode, $lib_dir = null) {}
 
 /**
@@ -518,8 +519,8 @@ function mcrypt_module_is_block_algorithm_mode ($mode, $lib_dir = null) {}
  * </p>
  * @return bool This function returns true if the specified algorithm is a block
  * algorithm, or false is it is a stream algorithm.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_module_is_block_algorithm ($algorithm, $lib_dir = null) {}
 
 /**
@@ -535,8 +536,8 @@ function mcrypt_module_is_block_algorithm ($algorithm, $lib_dir = null) {}
  * @return bool This function returns true if the mode outputs blocks of bytes or
  * false if it outputs just bytes. (e.g. true for cbc and ecb, and
  * false for cfb and stream).
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_module_is_block_mode ($mode, $lib_dir = null) {}
 
 /**
@@ -550,8 +551,8 @@ function mcrypt_module_is_block_mode ($mode, $lib_dir = null) {}
  * is on the system.
  * </p>
  * @return int the block size of the algorithm specified in bytes.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_module_get_algo_block_size ($algorithm, $lib_dir = null) {}
 
 /**
@@ -566,8 +567,8 @@ function mcrypt_module_get_algo_block_size ($algorithm, $lib_dir = null) {}
  * </p>
  * @return int This function returns the maximum supported key size of the
  * algorithm specified in bytes.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_module_get_algo_key_size ($algorithm, $lib_dir = null) {}
 
 /**
@@ -584,19 +585,19 @@ function mcrypt_module_get_algo_key_size ($algorithm, $lib_dir = null) {}
  * If it returns an empty array then all key sizes between 1 and
  * mcrypt_module_get_algo_key_size are supported by the
  * algorithm.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_module_get_supported_key_sizes ($algorithm, $lib_dir = null) {}
 
 /**
- * Close the mcrypt module
+ * Closes the mcrypt module
  * @link https://php.net/manual/en/function.mcrypt-module-close.php
  * @param resource $td <p>
  * The encryption descriptor.
  * </p>
  * @return bool true on success or false on failure.
- * @deprecated 7.1
  */
+#[Deprecated(since: '7.1')]
 function mcrypt_module_close ($td) {}
 
 define ('MCRYPT_ENCRYPT', 0);
