@@ -19,7 +19,7 @@ function msgpack_serialize($value) {}
  * </p>
  * @return mixed
  */
-function msgpack_unserialize($str, $object=NULL) {}
+function msgpack_unserialize($str, $object = null) {}
 
 /**
  * Alias of msgpack_serialize
@@ -42,7 +42,7 @@ function msgpack_unpack($str, $object = null)
 
 class MessagePack
 {
-    const OPT_PHPONLY = 1;
+    const OPT_PHPONLY = -1001;
 
     public function __construct($opt)
     {
