@@ -111,7 +111,7 @@ class Collection  {
      * @param mixed $document
      * @return \mysql_xdevapi\Result
      */
-    public function addOrReplaceOne($id,$document) : \mysql_xdevapi\Result {}
+    public function addOrReplaceOne($id, $document) : \mysql_xdevapi\Result {}
 
     /**
      * Get document count
@@ -134,7 +134,7 @@ class Collection  {
      * @param string $index_name
      * @return bool
      */
-    public function dropIndex($index_name, $index_desc_json) : bool {}
+    public function dropIndex($index_name) : bool {}
 
     /**
      * Check if collection exists in database
@@ -684,7 +684,7 @@ class DocResult implements \mysql_xdevapi\BaseResult, \Traversable {
     /**
      * Fetches warnings generated by MySQL server's last operation.
      * @link https://www.php.net/manual/en/mysql-xdevapi-docresult.getwarnings.php
-     * @return array|\mysql_xdevapi\Warning
+     * @return \mysql_xdevapi\Warning[]
      */
     public function getWarnings () : array {}
 
@@ -762,7 +762,7 @@ class Result implements \mysql_xdevapi\BaseResult , \Traversable {
     /**
      * Fetch the generated _id values from the last operation. The unique _id field is generated by the MySQL server.
      * @link https://www.php.net/manual/en/mysql-xdevapi-result.getgeneratedids.php
-     * @return array|string[]
+     * @return string[]
      */
     public function getGeneratedIds () : array {}
 
@@ -770,7 +770,7 @@ class Result implements \mysql_xdevapi\BaseResult , \Traversable {
     /**
      * Retrieve warnings from the last Result operation.
      * @link https://www.php.net/manual/en/mysql-xdevapi-result.getwarnings.php
-     * @return array|\mysql_xdevapi\Warning[]
+     * @return \mysql_xdevapi\Warning[]
      */
     public function getWarnings () : array {}
 
@@ -821,14 +821,14 @@ class RowResult implements \mysql_xdevapi\BaseResult , \Traversable {
     /**
      * Retrieve column metadata for columns present in the result set.
      * @link https://www.php.net/manual/en/mysql-xdevapi-rowresult.getcolumns.php
-     * @return array|\mysql_xdevapi\FieldMetadata[]
+     * @return \mysql_xdevapi\FieldMetadata[]
      */
     public function getColumns () : array {}
 
     /**
      * Retrieve warnings from the last RowResult operation.
      * @link https://www.php.net/manual/en/mysql-xdevapi-rowresult.getwarnings.php
-     * @return array|\mysql_xdevapi\Warning[]
+     * @return \mysql_xdevapi\Warning[]
      */
     public function getWarnings () : array {}
 
@@ -894,7 +894,7 @@ class Schema implements \mysql_xdevapi\DatabaseObject {
     /**
      * Fetch a list of collections for this schema.
      * @link https://www.php.net/manual/en/mysql-xdevapi-schema.getcollections.php
-     * @return array|\mysql_xdevapi\Collection[] Array of all collections in this schema, where each array element value is a Collection object with the collection name as the key.
+     * @return \mysql_xdevapi\Collection[] Array of all collections in this schema, where each array element value is a Collection object with the collection name as the key.
      */
     public function getCollections () : array {}
 
@@ -923,7 +923,7 @@ class Schema implements \mysql_xdevapi\DatabaseObject {
     /**
      * Get schema tables
      * @link https://www.php.net/manual/en/mysql-xdevapi-schema.gettables.php
-     * @return array|\mysql_xdevapi\Table[] Array of all tables in this schema, where each array element value is a Table object with the table name as the key.
+     * @return \mysql_xdevapi\Table[] Array of all tables in this schema, where each array element value is a Table object with the table name as the key.
      */
     public function getTables () : array {}
 }
@@ -1185,7 +1185,7 @@ class SqlStatementResult implements \mysql_xdevapi\BaseResult , \Traversable {
     /**
      * Get warnings from last operation
      * @link https://www.php.net/manual/en/mysql-xdevapi-sqlstatementresult.getwarnings.php
-     * @return array|\mysql_xdevapi\Warning[]
+     * @return \mysql_xdevapi\Warning[]
      */
     public function getWarnings () : array {}
 
