@@ -1,6 +1,7 @@
 <?php
 
 // Start of sqlite3 v.0.7-dev
+use JetBrains\PhpStorm\ArrayShape;
 
 /**
  * A class that interfaces SQLite 3 databases.
@@ -8,43 +9,43 @@
  */
 class SQLite3  {
 
-	const OK = 'OK';
-	const DENY = 'DENY';
-	const IGNORE = 'IGNORE';
-	const CREATE_INDEX = 'CREATE_INDEX';
-	const CREATE_TABLE = 'CREATE_TABLE';
-	const CREATE_TEMP_INDEX = 'CREATE_TEMP_INDEX';
-	const CREATE_TEMP_TABLE = 'CREATE_TEMP_TABLE';
-	const CREATE_TEMP_TRIGGER = 'CREATE_TEMP_TRIGGER';
-	const CREATE_TEMP_VIEW = 'CREATE_TEMP_VIEW';
-	const CREATE_TRIGGER = 'CREATE_TRIGGER';
-	const CREATE_VIEW = 'CREATE_VIEW';
-	const DELETE = 'DELETE';
-	const DROP_INDEX = 'DROP_INDEX';
-	const DROP_TABLE = 'DROP_TABLE';
-	const DROP_TEMP_INDEX = 'DROP_TEMP_INDEX';
-	const DROP_TEMP_TABLE = 'DROP_TEMP_TABLE';
-	const DROP_TEMP_TRIGGER = 'DROP_TEMP_TRIGGER';
-	const DROP_TEMP_VIEW = 'DROP_TEMP_VIEW';
-	const DROP_TRIGGER = 'DROP_TRIGGER';
-	const DROP_VIEW = 'DROP_VIEW';
-	const INSERT = 'INSERT';
-	const PRAGMA = 'PRAGMA';
-	const READ = 'READ';
-	const SELECT = 'SELECT';
-	const TRANSACTION = 'TRANSACTION';
-	const UPDATE = 'UPDATE';
-	const ATTACH = 'ATTACH';
-	const DETACH = 'DETACH';
-	const ALTER_TABLE = 'ALTER_TABLE';
-	const REINDEX = 'REINDEX';
-	const ANALYZE = 'ANALYZE';
-	const CREATE_VTABLE = 'CREATE_VTABLE';
-	const DROP_VTABLE = 'DROP_VTABLE';
-	const FUNCTION = 'FUNCTION';
-	const SAVEPOINT = 'SAVEPOINT';
-	const COPY = 'COPY';
-	const RECURSIVE = 'RECURSIVE';
+	const OK = 0;
+	const DENY = 1;
+	const IGNORE = 2;
+	const CREATE_INDEX = 1;
+	const CREATE_TABLE = 2;
+	const CREATE_TEMP_INDEX = 3;
+	const CREATE_TEMP_TABLE = 4;
+	const CREATE_TEMP_TRIGGER = 5;
+	const CREATE_TEMP_VIEW = 6;
+	const CREATE_TRIGGER = 7;
+	const CREATE_VIEW = 8;
+	const DELETE = 9;
+	const DROP_INDEX = 10;
+	const DROP_TABLE = 11;
+	const DROP_TEMP_INDEX = 12;
+	const DROP_TEMP_TABLE = 13;
+	const DROP_TEMP_TRIGGER = 14;
+	const DROP_TEMP_VIEW = 15;
+	const DROP_TRIGGER = 16;
+	const DROP_VIEW = 17;
+	const INSERT = 18;
+	const PRAGMA = 19;
+	const READ = 20;
+	const SELECT = 21;
+	const TRANSACTION = 22;
+	const UPDATE = 23;
+	const ATTACH = 24;
+	const DETACH = 25;
+	const ALTER_TABLE = 26;
+	const REINDEX = 27;
+	const ANALYZE = 28;
+	const CREATE_VTABLE = 29;
+	const DROP_VTABLE = 30;
+	const FUNCTION = 31;
+	const SAVEPOINT = 32;
+	const COPY = 0;
+	const RECURSIVE = 33;
 
 	/**
 	 * Opens an SQLite database
@@ -55,17 +56,18 @@ class SQLite3  {
 	 * @param int $flags [optional] <p>
 	 * Optional flags used to determine how to open the SQLite database. By
 	 * default, open uses SQLITE3_OPEN_READWRITE | SQLITE3_OPEN_CREATE.
+	 * </p>
 	 * <p>
 	 * SQLITE3_OPEN_READONLY: Open the database for
 	 * reading only.
 	 * </p>
-	 * @param string $encryption_key [optional] <p>
+	 * @param string $encryptionKey [optional] <p>
 	 * An optional encryption key used when encrypting and decrypting an
 	 * SQLite database.
 	 * </p>
 	 * @return void No value is returned.
 	 */
-	public function open ($filename, $flags = SQLITE3_OPEN_READWRITE | SQLITE3_OPEN_CREATE, $encryption_key = null) {}
+	public function open ($filename, $flags = SQLITE3_OPEN_READWRITE | SQLITE3_OPEN_CREATE, $encryptionKey = null) {}
 
 	/**
 	 * Closes the database connection
@@ -91,6 +93,7 @@ class SQLite3  {
 	 * @return array an associative array with the keys "versionString" and
 	 * "versionNumber".
 	 */
+	#[ArrayShape(["versionString" => "string", "versionNumber" => "int"])]
 	public static function version () {}
 
 	/**
@@ -118,25 +121,25 @@ class SQLite3  {
 	/**
 	 * Sets the busy connection handler
 	 * @link https://php.net/manual/en/sqlite3.busytimeout.php
-	 * @param int $msecs <p>
+	 * @param int $milliseconds <p>
 	 * The milliseconds to sleep. Setting this value to a value less than
 	 * or equal to zero, will turn off an already set timeout handler.
 	 * </p>
 	 * @return bool <b>TRUE</b> on success, <b>FALSE</b> on failure.
 	 * @since 5.3.3
 	 */
-	public function busyTimeout ($msecs) {}
+	public function busyTimeout ($milliseconds) {}
 
 	/**
 	 * Attempts to load an SQLite extension library
 	 * @link https://php.net/manual/en/sqlite3.loadextension.php
-	 * @param string $shared_library <p>
+	 * @param string $name <p>
 	 * The name of the library to load. The library must be located in the
 	 * directory specified in the configure option sqlite3.extension_dir.
 	 * </p>
 	 * @return bool <b>TRUE</b> if the extension is successfully loaded, <b>FALSE</b> on failure.
 	 */
-	public function loadExtension ($shared_library) {}
+	public function loadExtension ($name) {}
 
 	/**
 	 * Returns the number of database rows that were changed (or inserted or
@@ -151,13 +154,13 @@ class SQLite3  {
 	/**
 	 * Returns a string that has been properly escaped
 	 * @link https://php.net/manual/en/sqlite3.escapestring.php
-	 * @param string $value <p>
+	 * @param string $string <p>
 	 * The string to be escaped.
 	 * </p>
 	 * @return string a properly escaped string that may be used safely in an SQL
 	 * statement.
 	 */
-	public static function escapeString ($value) {}
+	public static function escapeString ($string) {}
 
 	/**
 	 * Prepares an SQL statement for execution
@@ -186,7 +189,7 @@ class SQLite3  {
 	 * @param string $query <p>
 	 * The SQL query to execute.
 	 * </p>
-	 * @param bool $entire_row [optional] <p>
+	 * @param bool $entireRow [optional] <p>
 	 * By default, <b>querySingle</b> returns the value of the
 	 * first column returned by the query. If
 	 * <i>entire_row</i> is <b>TRUE</b>, then it returns an array
@@ -203,7 +206,7 @@ class SQLite3  {
 	 * <p>
 	 * Invalid or failing queries will return <b>FALSE</b>.
 	 */
-	public function querySingle ($query, $entire_row = false) {}
+	public function querySingle ($query, $entireRow = false) {}
 
 	/**
 	 * Registers a PHP function for use as an SQL scalar function
@@ -215,7 +218,7 @@ class SQLite3  {
 	 * The name of a PHP function or user-defined function to apply as a
 	 * callback, defining the behavior of the SQL function.
 	 * </p>
-	 * @param int $argument_count [optional] <p>
+	 * @param int $argCount [optional] <p>
 	 * The number of arguments that the SQL function takes. If
 	 * this parameter is negative, then the SQL function may take
 	 * any number of arguments.
@@ -226,7 +229,7 @@ class SQLite3  {
 	 * the same result given the same inputs within a single SQL statement.</p>
 	 * @return bool <b>TRUE</b> upon successful creation of the function, <b>FALSE</b> on failure.
 	 */
-	public function createFunction ($name, $callback, $argument_count = -1, int $flags = 0) {}
+	public function createFunction ($name, $callback, $argCount = -1, int $flags = 0) {}
 
 	/**
 	 * Registers a PHP function for use as an SQL aggregate function
@@ -234,15 +237,15 @@ class SQLite3  {
 	 * @param string $name <p>
 	 * Name of the SQL aggregate to be created or redefined.
 	 * </p>
-	 * @param mixed $step_callback <p>
+	 * @param mixed $stepCallback <p>
 	 * The name of a PHP function or user-defined function to apply as a
 	 * callback for every item in the aggregate.
 	 * </p>
-	 * @param mixed $final_callback <p>
+	 * @param mixed $finalCallback <p>
 	 * The name of a PHP function or user-defined function to apply as a
 	 * callback at the end of the aggregate data.
 	 * </p>
-	 * @param int $argument_count [optional] <p>
+	 * @param int $argCount [optional] <p>
 	 * The number of arguments that the SQL aggregate takes. If
 	 * this parameter is negative, then the SQL aggregate may take
 	 * any number of arguments.
@@ -250,7 +253,7 @@ class SQLite3  {
 	 * @return bool <b>TRUE</b> upon successful creation of the aggregate, <b>FALSE</b> on
 	 * failure.
 	 */
-	public function createAggregate ($name, $step_callback, $final_callback, $argument_count = -1) {}
+	public function createAggregate ($name, $stepCallback, $finalCallback, $argCount = -1) {}
 
 	/**
 	 * Registers a PHP function for use as an SQL collating function
@@ -273,20 +276,23 @@ class SQLite3  {
 	/**
 	 * Opens a stream resource to read a BLOB
 	 * @link https://php.net/manual/en/sqlite3.openblob.php
-	 * @param $table <p>The table name.</p>
-	 * @param $column <p>The column name.</p>
-	 * @param $rowid <p>The row ID.</p>
-	 * @param $dbname [optional] <p>The symbolic name of the DB</p>
+	 * @param string $table <p>The table name.</p>
+	 * @param string $column <p>The column name.</p>
+	 * @param int $rowid <p>The row ID.</p>
+	 * @param string $database [optional] <p>The symbolic name of the DB</p>
 	 * @param int $flags [optional]
-	 * <p>Either <b>SQLITE3_OPEN_READONLY</b> or <b>SQLITE3_OPEN_READWRITE</b> to open the stream for reading only, or for reading and writing, respectively.</p?
+	 * <p>Either <b>SQLITE3_OPEN_READONLY</b> or <b>SQLITE3_OPEN_READWRITE</b> to open the stream for reading only, or for reading and writing, respectively.</p>
 	 * @return resource|false Returns a stream resource, or FALSE on failure.
 	 */
-	public function openBlob ($table, $column, $rowid, $dbname, int $flags = SQLITE3_OPEN_READONLY) {}
+	public function openBlob ($table, $column, $rowid, $database, int $flags = SQLITE3_OPEN_READONLY) {}
 
 	/**
-	 * @param $enableExceptions
+	 * Enable throwing exceptions
+	 * @link https://www.php.net/manual/en/sqlite3.enableexceptions
+	 * @param bool $enable
+	 * @return bool Returns the old value; true if exceptions were enabled, false otherwise.
 	 */
-	public function enableExceptions ($enableExceptions) {}
+	public function enableExceptions ($enable) {}
 
 	/**
 	 * Instantiates an SQLite3 object and opens an SQLite 3 database
@@ -297,16 +303,17 @@ class SQLite3  {
 	 * @param int $flags [optional] <p>
 	 * Optional flags used to determine how to open the SQLite database. By
 	 * default, open uses SQLITE3_OPEN_READWRITE | SQLITE3_OPEN_CREATE.
+	 * </p>
 	 * <p>
 	 * SQLITE3_OPEN_READONLY: Open the database for
 	 * reading only.
 	 * </p>
-	 * @param string $encryption_key [optional] <p>
+	 * @param string $encryptionKey [optional] <p>
 	 * An optional encryption key used when encrypting and decrypting an
 	 * SQLite database.
 	 * </p>
 	 */
-	public function __construct ($filename, $flags = null, $encryption_key = null) {}
+	public function __construct ($filename, $flags = null, $encryptionKey = null) {}
 
 	/**
 	 * @return int
@@ -321,14 +328,15 @@ class SQLite3  {
 	public function enableExtendedResultCodes($enable){}
 
 	/**
-	 * @param $destination_db
-	 * @param $source_dbname
-	 * @param $destination_dbname
+	 * @param $destination
+	 * @param $sourceDatabase
+	 * @param $destinationDatabase
 	 * @since 7.4
 	 */
-	public function backup($destination_db, $source_dbname, $destination_dbname){}
+	public function backup($destination, $sourceDatabase, $destinationDatabase){}
 
 	/**
+	 * @param null|callable $callback
 	 * @return bool
 	 * @since 8.0
 	 */
@@ -382,15 +390,16 @@ class SQLite3Stmt  {
 	/**
 	 * Binds a parameter to a statement variable
 	 * @link https://php.net/manual/en/sqlite3stmt.bindparam.php
-	 * @param string $sql_param <p>
+	 * @param string $param <p>
 	 * An string identifying the statement variable to which the
 	 * parameter should be bound.
 	 * </p>
-	 * @param mixed &$param <p>
+	 * @param mixed &$var <p>
 	 * The parameter to bind to a statement variable.
 	 * </p>
 	 * @param int $type [optional] <p>
 	 * The data type of the parameter to bind.
+	 * </p>
 	 * <p>
 	 * SQLITE3_INTEGER: The value is a signed integer,
 	 * stored in 1, 2, 3, 4, 6, or 8 bytes depending on the magnitude of
@@ -399,12 +408,12 @@ class SQLite3Stmt  {
 	 * @return bool <b>TRUE</b> if the parameter is bound to the statement variable, <b>FALSE</b>
 	 * on failure.
 	 */
-	public function bindParam ($sql_param, &$param, $type = null) {}
+	public function bindParam ($param, &$var, $type = null) {}
 
 	/**
 	 * Binds the value of a parameter to a statement variable
 	 * @link https://php.net/manual/en/sqlite3stmt.bindvalue.php
-	 * @param string $sql_param <p>
+	 * @param string $param <p>
 	 * An string identifying the statement variable to which the
 	 * value should be bound.
 	 * </p>
@@ -413,6 +422,7 @@ class SQLite3Stmt  {
 	 * </p>
 	 * @param int $type [optional] <p>
 	 * The data type of the value to bind.
+	 * </p>
 	 * <p>
 	 * SQLITE3_INTEGER: The value is a signed integer,
 	 * stored in 1, 2, 3, 4, 6, or 8 bytes depending on the magnitude of
@@ -421,24 +431,24 @@ class SQLite3Stmt  {
 	 * @return bool <b>TRUE</b> if the value is bound to the statement variable, <b>FALSE</b>
 	 * on failure.
 	 */
-	public function bindValue ($sql_param, $value, $type = null) {}
+	public function bindValue ($param, $value, $type = null) {}
 
 	public function readOnly () {}
 
 	/**
 	 * @param SQLite3 $sqlite3
-	 * @param string $sql
+	 * @param string $query
 	 */
-	private function __construct ($sqlite3, $sql) {}
+	private function __construct ($sqlite3, $query) {}
 
 	/**
 	 * Retrieves the SQL of the prepared statement. If expanded is FALSE, the unmodified SQL is retrieved.
 	 * If expanded is TRUE, all query parameters are replaced with their bound values, or with an SQL NULL, if not already bound.
-	 * @param bool $expanded Whether to retrieve the expanded SQL. Passing TRUE is only supported as of libsqlite 3.14.
+	 * @param bool $expand Whether to retrieve the expanded SQL. Passing TRUE is only supported as of libsqlite 3.14.
 	 * @return string|false Returns the SQL of the prepared statement, or FALSE on failure.
 	 * @since 7.4
 	 */
-	public function getSQL($expanded = false){}
+	public function getSQL($expand = false){}
 
 }
 
@@ -458,18 +468,18 @@ class SQLite3Result  {
 	/**
 	 * Returns the name of the nth column
 	 * @link https://php.net/manual/en/sqlite3result.columnname.php
-	 * @param int $column_number <p>
+	 * @param int $column <p>
 	 * The numeric zero-based index of the column.
 	 * </p>
 	 * @return string the string name of the column identified by
 	 * <i>column_number</i>.
 	 */
-	public function columnName ($column_number) {}
+	public function columnName ($column) {}
 
 	/**
 	 * Returns the type of the nth column
 	 * @link https://php.net/manual/en/sqlite3result.columntype.php
-	 * @param int $column_number <p>
+	 * @param int $column <p>
 	 * The numeric zero-based index of the column.
 	 * </p>
 	 * @return int the data type index of the column identified by
@@ -478,7 +488,7 @@ class SQLite3Result  {
 	 * <b>SQLITE3_TEXT</b>, <b>SQLITE3_BLOB</b>, or
 	 * <b>SQLITE3_NULL</b>).
 	 */
-	public function columnType ($column_number) {}
+	public function columnType ($column) {}
 
 	/**
 	 * Fetches a result row as an associative or numerically indexed array or both
@@ -487,6 +497,7 @@ class SQLite3Result  {
 	 * Controls how the next row will be returned to the caller. This value
 	 * must be one of either SQLITE3_ASSOC,
 	 * SQLITE3_NUM, or SQLITE3_BOTH.
+	 * </p>
 	 * <p>
 	 * SQLITE3_ASSOC: returns an array indexed by column
 	 * name as returned in the corresponding result set
