@@ -1,21 +1,25 @@
 <?php
 
+use JetBrains\PhpStorm\ArrayShape;
+use JetBrains\PhpStorm\Deprecated;
+use JetBrains\PhpStorm\Pure;
+
 /**
  * Runs the equivalent of the select() system call on the given
  * arrays of streams with a timeout specified by tv_sec and tv_usec
  * @link https://php.net/manual/en/function.stream-select.php
- * @param array &$read <p>
+ * @param array|null &$read <p>
  * The streams listed in the read array will be watched to
  * see if characters become available for reading (more precisely, to see if
  * a read will not block - in particular, a stream resource is also ready on
  * end-of-file, in which case an fread will return
  * a zero length string).
  * </p>
- * @param array &$write <p>
+ * @param array|null &$write <p>
  * The streams listed in the write array will be
  * watched to see if a write will not block.
  * </p>
- * @param array &$except <p>
+ * @param array|null &$except <p>
  * The streams listed in the except array will be
  * watched for high priority exceptional ("out-of-band") data arriving.
  * </p>
@@ -30,7 +34,7 @@
  * empty array or null instead. Also do not forget that those arrays are
  * passed by reference and will be modified after
  * stream_select returns.
- * @param int $tv_sec <p>
+ * @param int|null $seconds <p>
  * The tv_sec and tv_usec
  * together form the timeout parameter,
  * tv_sec specifies the number of seconds while
@@ -64,19 +68,20 @@
  * stream_select will return as soon as the
  * requested streams are ready for use.
  * </p>
- * @param int $tv_usec [optional] <p>
+ * @param int $microseconds [optional] <p>
  * See tv_sec description.
  * </p>
- * @return int On success stream_select returns the number of
+ * @return int|false On success stream_select returns the number of
  * stream resources contained in the modified arrays, which may be zero if
  * the timeout expires before anything interesting happens. On error false
  * is returned and a warning raised (this can happen if the system call is
  * interrupted by an incoming signal).
  */
-function stream_select (array &$read, array &$write, array &$except, $tv_sec, $tv_usec = null) {}
+function stream_select (?array &$read, ?array &$write, ?array &$except, ?int $seconds, int $microseconds): int|false
+{}
 
 /**
- * Create a streams context
+ * Create a stream context
  * @link https://php.net/manual/en/function.stream-context-create.php
  * @param null|array $options [optional] <p>
  * Must be an associative array of associative arrays in the format
@@ -93,12 +98,12 @@ function stream_select (array &$read, array &$write, array &$except, $tv_sec, $t
  * </p>
  * @return resource A stream context resource.
  */
-function stream_context_create (array $options = null, array $params = null) {}
+function stream_context_create (?array $options, ?array $params) {}
 
 /**
  * Set parameters for a stream/wrapper/context
  * @link https://php.net/manual/en/function.stream-context-set-params.php
- * @param resource $stream_or_context <p>
+ * @param resource $context <p>
  * The stream or context to apply the parameters too.
  * </p>
  * @param array $params <p>
@@ -110,31 +115,34 @@ function stream_context_create (array $options = null, array $params = null) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function stream_context_set_params ($stream_or_context, array $params) {}
+function stream_context_set_params ($context, array $params): bool
+{}
 
 /**
  * Retrieves parameters from a context
  * @link https://php.net/manual/en/function.stream-context-get-params.php
- * @param resource $stream_or_context <p>
+ * @param resource $context <p>
  * A stream resource or a
  * context resource
  * </p>
  * @return array an associate array containing all context options and parameters.
  */
-function stream_context_get_params ($stream_or_context) {}
+function stream_context_get_params ($context): array
+{}
 
 /**
  * Sets an option for a stream/wrapper/context
  * @link https://php.net/manual/en/function.stream-context-set-option.php
- * @param resource $stream_or_context <p>
+ * @param resource $context <p>
  * The stream or context resource to apply the options too.
  * </p>
- * @param string $wrapper
- * @param string $option
+ * @param string $wrapper_or_options
+ * @param string $option_name
  * @param mixed $value
  * @return bool true on success or false on failure.
  */
-function stream_context_set_option ($stream_or_context, $wrapper, $option, $value) {}
+function stream_context_set_option ($context, string $wrapper_or_options, string $option_name, mixed $value): bool
+{}
 
 /**
  * Sets an option for a stream/wrapper/context
@@ -143,7 +151,8 @@ function stream_context_set_option ($stream_or_context, $wrapper, $option, $valu
  * @param array $options The options to set for the default context.
  * @return bool true on success or false on failure.
  */
-function stream_context_set_option ($stream_or_context, array $options) {}
+function stream_context_set_option ($stream_or_context, array $options): bool
+{}
 
 /**
  * Retrieve options for a stream/wrapper/context
@@ -153,10 +162,11 @@ function stream_context_set_option ($stream_or_context, array $options) {}
  * </p>
  * @return array an associative array with the options.
  */
-function stream_context_get_options ($stream_or_context) {}
+function stream_context_get_options ($stream_or_context): array
+{}
 
 /**
- * Retreive the default streams context
+ * Retreive the default stream context
  * @link https://php.net/manual/en/function.stream-context-get-default.php
  * @param null|array $options [optional] options must be an associative
  * array of associative arrays in the format
@@ -167,10 +177,10 @@ function stream_context_get_options ($stream_or_context) {}
  * </p>
  * @return resource A stream context resource.
  */
-function stream_context_get_default (array $options = null) {}
+function stream_context_get_default (?array $options) {}
 
 /**
- * Set the default streams context
+ * Set the default stream context
  * @link https://php.net/manual/en/function.stream-context-set-default.php
  * @param array $options <p>
  * The options to set for the default context.
@@ -190,10 +200,10 @@ function stream_context_set_default (array $options) {}
  * @param resource $stream <p>
  * The target stream.
  * </p>
- * @param string $filtername <p>
+ * @param string $filter_name <p>
  * The filter name.
  * </p>
- * @param int $read_write [optional] <p>
+ * @param int $mode [optional] <p>
  * By default, stream_filter_prepend will
  * attach the filter to the read filter chain
  * if the file was opened for reading (i.e. File Mode:
@@ -217,7 +227,8 @@ function stream_context_set_default (array $options) {}
  * @return resource|false a resource which can be used to refer to this filter
  * instance during a call to stream_filter_remove.
  */
-function stream_filter_prepend ($stream, $filtername, $read_write = null, $params = null) {}
+function stream_filter_prepend ($stream, string $filter_name, int $mode, mixed $params)
+{}
 
 /**
  * Attach a filter to a stream
@@ -225,10 +236,10 @@ function stream_filter_prepend ($stream, $filtername, $read_write = null, $param
  * @param resource $stream <p>
  * The target stream.
  * </p>
- * @param string $filtername <p>
+ * @param string $filter_name <p>
  * The filter name.
  * </p>
- * @param int $read_write [optional] <p>
+ * @param int $mode [optional] <p>
  * By default, stream_filter_append will
  * attach the filter to the read filter chain
  * if the file was opened for reading (i.e. File Mode:
@@ -251,7 +262,8 @@ function stream_filter_prepend ($stream, $filtername, $read_write = null, $param
  * @return resource|false a resource which can be used to refer to this filter
  * instance during a call to stream_filter_remove.
  */
-function stream_filter_append ($stream, $filtername, $read_write = null, $params = null) {}
+function stream_filter_append ($stream, string $filter_name, int $mode, mixed $params)
+{}
 
 /**
  * Remove a filter from a stream
@@ -261,18 +273,19 @@ function stream_filter_append ($stream, $filtername, $read_write = null, $params
  * </p>
  * @return bool true on success or false on failure.
  */
-function stream_filter_remove ($stream_filter) {}
+function stream_filter_remove ($stream_filter): bool
+{}
 
 /**
  * Open Internet or Unix domain socket connection
  * @link https://php.net/manual/en/function.stream-socket-client.php
- * @param string $remote_socket <p>
+ * @param string $address <p>
  * Address to the socket to connect to.
  * </p>
- * @param int &$errno [optional] <p>
+ * @param int &$error_code [optional] <p>
  * Will be set to the system level error number if connection fails.
  * </p>
- * @param string &$errstr [optional] <p>
+ * @param string &$error_message [optional] <p>
  * Will be set to the system level error message if the connection fails.
  * </p>
  * @param float|null $timeout [optional] <p>
@@ -303,12 +316,13 @@ function stream_filter_remove ($stream_filter) {}
  * fwrite, fclose, and
  * feof), false on failure.
  */
-function stream_socket_client ($remote_socket, &$errno = null, &$errstr = null, $timeout = null, $flags = null, $context = null) {}
+function stream_socket_client (string $address, &$error_code, &$error_message, ?float $timeout, int $flags, $context)
+{}
 
 /**
  * Create an Internet or Unix domain server socket
  * @link https://php.net/manual/en/function.stream-socket-server.php
- * @param string $local_socket <p>
+ * @param string $address <p>
  * The type of socket created is determined by the transport specified
  * using standard URL formatting: transport://target.
  * </p>
@@ -326,7 +340,7 @@ function stream_socket_client ($remote_socket, &$errno = null, &$errstr = null,
  * stream_get_transports. See
  * for a list of bulitin transports.
  * </p>
- * @param int &$errno [optional] <p>
+ * @param int &$error_code [optional] <p>
  * If the optional errno and errstr
  * arguments are present they will be set to indicate the actual system
  * level error that occurred in the system-level socket(),
@@ -338,7 +352,7 @@ function stream_socket_client ($remote_socket, &$errno = null, &$errstr = null,
  * Note that the errno and
  * errstr arguments will always be passed by reference.
  * </p>
- * @param string &$errstr [optional] <p>
+ * @param string &$error_message [optional] <p>
  * See errno description.
  * </p>
  * @param int $flags [optional] <p>
@@ -353,17 +367,18 @@ function stream_socket_client ($remote_socket, &$errno = null, &$errstr = null,
  * </p>
  * @return resource|false the created stream, or false on error.
  */
-function stream_socket_server ($local_socket, &$errno = null, &$errstr = null, $flags = null, $context = null) {}
+function stream_socket_server (string $address, &$error_code, &$error_message, int $flags, $context)
+{}
 
 /**
- * Accept a connection on a socket created by <function>stream_socket_server</function>
+ * Accept a connection on a socket created by {@see stream_socket_server}
  * @link https://php.net/manual/en/function.stream-socket-accept.php
- * @param resource $server_socket
- * @param float $timeout [optional] <p>
+ * @param resource $socket
+ * @param float|null $timeout [optional] <p>
  * Override the default socket accept timeout. Time should be given in
  * seconds.
  * </p>
- * @param string &$peername [optional] <p>
+ * @param string &$peer_name [optional] <p>
  * Will be set to the name (address) of the client which connected, if
  * included and available from the selected transport.
  * </p>
@@ -373,21 +388,23 @@ function stream_socket_server ($local_socket, &$errno = null, &$errstr = null, $
  * </p>
  * @return resource|false Returns a stream to the accepted socket connection or FALSE on failure.
  */
-function stream_socket_accept ($server_socket, $timeout = null, &$peername = null) {}
+function stream_socket_accept ($socket, ?float $timeout, &$peer_name)
+{}
 
 /**
  * Retrieve the name of the local or remote sockets
  * @link https://php.net/manual/en/function.stream-socket-get-name.php
- * @param resource $handle <p>
+ * @param resource $socket <p>
  * The socket to get the name of.
  * </p>
- * @param bool $want_peer <p>
+ * @param bool $remote <p>
  * If set to true the remote socket name will be returned, if set
  * to false the local socket name will be returned.
  * </p>
  * @return string|false The name of the socket or false on error.
  */
-function stream_socket_get_name ($handle, $want_peer) {}
+function stream_socket_get_name ($socket, bool $remote): string|false
+{}
 
 /**
  * Receives data from a socket, connected or not
@@ -426,7 +443,8 @@ function stream_socket_get_name ($handle, $want_peer) {}
  * </p>
  * @return string|false the read data, as a string, or false on error
  */
-function stream_socket_recvfrom ($socket, $length, $flags = null, &$address = null) {}
+function stream_socket_recvfrom ($socket, int $length, int $flags, &$address): string|false
+{}
 
 /**
  * Sends a message to a socket, whether it is connected or not
@@ -459,7 +477,8 @@ function stream_socket_recvfrom ($socket, $length, $flags = null, &$address = nu
  * </p>
  * @return int|false a result code, as an integer.
  */
-function stream_socket_sendto ($socket, $data, $flags = null, $address = null) {}
+function stream_socket_sendto ($socket, string $data, int $flags, string $address): int|false
+{}
 
 /**
  * Turns encryption on/off on an already connected socket
@@ -470,10 +489,10 @@ function stream_socket_sendto ($socket, $data, $flags = null, $address = null) {
  * @param bool $enable <p>
  * Enable/disable cryptography on the stream.
  * </p>
- * @param int $crypto_type [optional] <p>
+ * @param int|null $crypto_method [optional] <p>
  * Setup encryption on the stream.
- * Valid methods are
- * STREAM_CRYPTO_METHOD_SSLv2_CLIENT
+ * Valid methods are:<br>
+ * STREAM_CRYPTO_METHOD_SSLv2_CLIENT</p>
  * @param resource $session_stream [optional] <p>
  * Seed the stream with settings from session_stream.
  * </p>
@@ -481,7 +500,8 @@ function stream_socket_sendto ($socket, $data, $flags = null, $address = null) {
  * 0 if there isn't enough data and you should try again
  * (only for non-blocking sockets).
  */
-function stream_socket_enable_crypto ($stream, $enable, $crypto_type = null, $session_stream = null) {}
+function stream_socket_enable_crypto ($stream, bool $enable, ?int $crypto_method, $session_stream): int|bool
+{}
 
 /**
  * Shutdown a full-duplex connection
@@ -490,7 +510,7 @@ function stream_socket_enable_crypto ($stream, $enable, $crypto_type = null, $se
  * An open stream (opened with stream_socket_client,
  * for example)
  * </p>
- * @param int $how <p>
+ * @param int $mode <p>
  * One of the following constants: STREAM_SHUT_RD
  * (disable further receptions), STREAM_SHUT_WR
  * (disable further transmissions) or
@@ -500,7 +520,8 @@ function stream_socket_enable_crypto ($stream, $enable, $crypto_type = null, $se
  * @return bool true on success or false on failure.
  * @since 5.2.1
  */
-function stream_socket_shutdown ($stream, $how) {}
+function stream_socket_shutdown ($stream, int $mode): bool
+{}
 
 /**
  * Creates a pair of connected, indistinguishable socket streams
@@ -528,18 +549,19 @@ function stream_socket_shutdown ($stream, $how) {}
  * @return array|false an array with the two socket resources on success, or
  * false on failure.
  */
-function stream_socket_pair ($domain, $type, $protocol) {}
+function stream_socket_pair (int $domain, int $type, int $protocol): array|false
+{}
 
 /**
  * Copies data from one stream to another
  * @link https://php.net/manual/en/function.stream-copy-to-stream.php
- * @param resource $source <p>
+ * @param resource $from <p>
  * The source stream
  * </p>
- * @param resource $dest <p>
+ * @param resource $to <p>
  * The destination stream
  * </p>
- * @param int $maxlength [optional] <p>
+ * @param int|null $length [optional] <p>
  * Maximum bytes to copy
  * </p>
  * @param int $offset [optional] <p>
@@ -547,15 +569,16 @@ function stream_socket_pair ($domain, $type, $protocol) {}
  * </p>
  * @return int|false the total count of bytes copied, or false on failure.
  */
-function stream_copy_to_stream ($source, $dest, $maxlength = null, $offset = null) {}
+function stream_copy_to_stream ($from, $to, ?int $length, int $offset): int|false
+{}
 
 /**
  * Reads remainder of a stream into a string
  * @link https://php.net/manual/en/function.stream-get-contents.php
- * @param resource $handle <p>
+ * @param resource $stream <p>
  * A stream resource (e.g. returned from fopen)
  * </p>
- * @param int $maxlength [optional] <p>
+ * @param int|null $length [optional] <p>
  * The maximum bytes to read. Defaults to -1 (read all the remaining
  * buffer).
  * </p>
@@ -564,7 +587,8 @@ function stream_copy_to_stream ($source, $dest, $maxlength = null, $offset = nul
  * </p>
  * @return string|false a string or false on failure.
  */
-function stream_get_contents ($handle, $maxlength = null, $offset = null) {}
+function stream_get_contents ($stream, ?int $length = -1, int $offset = -1): string|false
+{}
 
 /**
  * Tells whether the stream supports locking.
@@ -574,24 +598,25 @@ function stream_get_contents ($handle, $maxlength = null, $offset = null) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function stream_supports_lock ($stream) {}
+function stream_supports_lock ($stream): bool
+{}
 
 /**
  * Gets line from file pointer and parse for CSV fields
  * @link https://php.net/manual/en/function.fgetcsv.php
- * @param resource $handle <p>
+ * @param resource $stream <p>
  * A valid file pointer to a file successfully opened by
  * fopen, popen, or
  * fsockopen.
  * </p>
- * @param int $length [optional] <p>
+ * @param int|null $length [optional] <p>
  * Must be greater than the longest line (in characters) to be found in
  * the CSV file (allowing for trailing line-end characters). It became
  * optional in PHP 5. Omitting this parameter (or setting it to 0 in PHP
  * 5.0.4 and later) the maximum line length is not limited, which is
  * slightly slower.
  * </p>
- * @param string $delimiter [optional] <p>
+ * @param string $separator [optional] <p>
  * Set the field delimiter (one character only).
  * </p>
  * @param string $enclosure [optional] <p>
@@ -600,29 +625,29 @@ function stream_supports_lock ($stream) {}
  * @param string $escape [optional] <p>
  * Set the escape character (one character only). Defaults as a backslash.
  * </p>
- * @return array|null|false an indexed array containing the fields read.
- * </p>
+ * @return array|false an indexed array containing the fields read.
  * <p>
  * A blank line in a CSV file will be returned as an array
  * comprising a single null field, and will not be treated
  * as an error.
  * </p>
- * &note.line-endings;
  * <p>
  * fgetcsv returns null if an invalid
  * handle is supplied or false on other errors,
  * including end of file.
+ * </p>
  */
-function fgetcsv ($handle, $length = 0, $delimiter = ',', $enclosure = '"', $escape = '\\') {}
+function fgetcsv ($stream, ?int $length = 0, string $separator = ',', string $enclosure = '"', string $escape = '\\'): array|false
+{}
 
 /**
  * Format line as CSV and write to file pointer
  * @link https://php.net/manual/en/function.fputcsv.php
- * @param resource $handle The file pointer must be valid, and must point to a file successfully opened by fopen() or fsockopen() (and not yet closed by fclose()).
+ * @param resource $stream The file pointer must be valid, and must point to a file successfully opened by fopen() or fsockopen() (and not yet closed by fclose()).
  * @param array $fields <p>
  * An array of values.
  * </p>
- * @param string $delimiter [optional] <p>
+ * @param string $separator [optional] <p>
  * The optional delimiter parameter sets the field
  * delimiter (one character only).
  * </p>
@@ -630,27 +655,31 @@ function fgetcsv ($handle, $length = 0, $delimiter = ',', $enclosure = '"', $esc
  * The optional enclosure parameter sets the field
  * enclosure (one character only).
  * </p>
- * @param string $escape_char The optional escape_char parameter sets the escape character (one character only).
+ * @param string $escape [optional] <p>
+ * The optional escape_char parameter sets the escape character (one character only).
+ * </p>
  * @return int|false the length of the written string or false on failure.
  */
-function fputcsv ($handle, array $fields, $delimiter = ",", $enclosure = '"', $escape_char = "\\") {}
+function fputcsv ($stream, array $fields, string $separator = ",", string $enclosure = '"', string $escape = "\\"): int|false
+{}
 
 /**
  * Portable advisory file locking
  * @link https://php.net/manual/en/function.flock.php
- * @param resource $handle <p>
+ * @param resource $stream <p>
  * An open file pointer.
  * </p>
  * @param int $operation <p>
  * operation is one of the following:
- * LOCK_SH to acquire a shared lock (reader).
- * @param int &$wouldblock [optional] <p>
- * The optional third argument is set to true if the lock would block
+ * LOCK_SH to acquire a shared lock (reader).</p>
+ * @param int &$would_block [optional] <p>
+ * The optional third argument is set to 1 if the lock would block
  * (EWOULDBLOCK errno condition).
  * </p>
  * @return bool true on success or false on failure.
  */
-function flock ($handle, $operation, &$wouldblock = null) {}
+function flock ($stream, int $operation, &$would_block): bool
+{}
 
 /**
  * Extracts all meta tag content attributes from a file and returns an array
@@ -679,8 +708,7 @@ function flock ($handle, $operation, &$wouldblock = null) {}
  * the include_path directive.
  * This is used for local files, not URLs.
  * </p>
- * @return array an array with all the parsed meta tags.
- * </p>
+ * @return array|false an array with all the parsed meta tags.
  * <p>
  * The value of the name property becomes the key, the value of the content
  * property becomes the value of the returned array, so you can easily use
@@ -688,16 +716,19 @@ function flock ($handle, $operation, &$wouldblock = null) {}
  * Special characters in the value of the name property are substituted with
  * '_', the rest is converted to lower case. If two meta tags have the same
  * name, only the last one is returned.
+ * </p>
  */
-function get_meta_tags ($filename, $use_include_path = null) {}
+#[Pure]
+function get_meta_tags (string $filename, bool $use_include_path): array|false
+{}
 
 /**
- * Sets file buffering on the given stream
+ * Sets write file buffering on the given stream
  * @link https://php.net/manual/en/function.stream-set-write-buffer.php
  * @param resource $stream <p>
  * The file pointer.
  * </p>
- * @param int $buffer <p>
+ * @param int $size <p>
  * The number of bytes to buffer. If buffer
  * is 0 then write operations are unbuffered. This ensures that all writes
  * with fwrite are completed before other processes are
@@ -706,15 +737,16 @@ function get_meta_tags ($filename, $use_include_path = null) {}
  * @return int 0 on success, or EOF if the request cannot be honored.
  * @see stream_set_read_buffer()
  */
-function stream_set_write_buffer ($stream, $buffer) {}
+function stream_set_write_buffer ($stream, int $size): int
+{}
 
 /**
- * Sets file buffering on the given stream
+ * Sets read file buffering on the given stream
  * @link https://php.net/manual/en/function.stream-set-read-buffer.php
  * @param resource $stream <p>
  * The file pointer.
  * </p>
- * @param int $buffer <p>
+ * @param int $size <p>
  * The number of bytes to buffer. If buffer
  * is 0 then write operations are unbuffered. This ensures that all writes
  * with fwrite are completed before other processes are
@@ -723,36 +755,44 @@ function stream_set_write_buffer ($stream, $buffer) {}
  * @return int 0 on success, or EOF if the request cannot be honored.
  * @see stream_set_write_buffer()
  */
-function stream_set_read_buffer ($stream, $buffer) {}
+function stream_set_read_buffer ($stream, int $size): int
+{}
 
 /**
- * &Alias; <function>stream_set_write_buffer</function>
+ * Alias:
+ * {@see stream_set_write_buffer}
  * <p>Sets the buffering for write operations on the given stream to buffer bytes.
  * Output using fwrite() is normally buffered at 8K.
  * This means that if there are two processes wanting to write to the same output stream (a file),
  * each is paused after 8K of data to allow the other to write.
+ * </p>
  * @link https://php.net/manual/en/function.set-file-buffer.php
- * @param resource $fp The file pointer.
- * @param int $buffer The number of bytes to buffer. If buffer is 0 then write operations are unbuffered.
+ * @param resource $stream The file pointer.
+ * @param int $size The number of bytes to buffer. If buffer is 0 then write operations are unbuffered.
  * This ensures that all writes with fwrite() are completed before other processes are allowed to write to that output stream.
  * @return int
  */
-function set_file_buffer ($fp, $buffer) {}
+function set_file_buffer ($stream, int $size): int
+{}
 
 /**
- * &Alias; <function>stream_set_blocking</function>
+ * Alias:
+ * {@see stream_set_blocking}
  * <p>Sets blocking or non-blocking mode on a stream.
- * This function works for any stream that supports non-blocking mode (currently, regular files and socket streams).
+ * This function works for any stream that supports non-blocking mode (currently, regular files and socket streams)
+ * </p>
  * @link https://php.net/manual/en/function.set-socket-blocking.php
- * @deprecated 5.3 use stream_set_blocking() instead
  * @param resource $socket
  * @param bool $mode If mode is FALSE, the given stream will be switched to non-blocking mode, and if TRUE, it will be switched to blocking mode.
  * This affects calls like fgets() and fread() that read from the stream.
  * In non-blocking mode an fgets() call will always return right away while in blocking mode it will wait for data to become available on the stream.
  * @return bool Returns TRUE on success or FALSE on failure.
  * @removed 7.0
+ * @see stream_set_blocking()
  */
-function set_socket_blocking ($socket, $mode) {}
+#[Deprecated(replacement: "stream_set_blocking(%parametersList%)", since: 5.3)]
+function set_socket_blocking ($socket, bool $mode): bool
+{}
 
 /**
  * Set blocking/non-blocking mode on a stream
@@ -760,7 +800,7 @@ function set_socket_blocking ($socket, $mode) {}
  * @param resource $stream <p>
  * The stream.
  * </p>
- * @param bool $mode <p>
+ * @param bool $enable <p>
  * If mode is FALSE, the given stream
  * will be switched to non-blocking mode, and if TRUE, it
  * will be switched to blocking mode. This affects calls like
@@ -772,15 +812,17 @@ function set_socket_blocking ($socket, $mode) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function stream_set_blocking ($stream, $mode) {}
+function stream_set_blocking ($stream, bool $enable): bool
+{}
 
 /**
- * &Alias; <function>stream_set_blocking</function>
+ * Alias:
+ * {@see stream_set_blocking}
  * @link https://php.net/manual/en/function.socket-set-blocking.php
- * @param resource $socket <p>
+ * @param resource $stream <p>
  * The stream.
  * </p>
- * @param bool $mode <p>
+ * @param bool $enable <p>
  * If mode is FALSE, the given stream
  * will be switched to non-blocking mode, and if TRUE, it
  * will be switched to blocking mode. This affects calls like
@@ -792,7 +834,8 @@ function stream_set_blocking ($stream, $mode) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function socket_set_blocking ($socket, $mode) {}
+function socket_set_blocking ($stream, bool $enable): bool
+{}
 
 /**
  * Retrieves header/meta data from streams/file pointers
@@ -802,7 +845,6 @@ function socket_set_blocking ($socket, $mode) {}
  * fsockopen and pfsockopen.
  * </p>
  * @return array The result array contains the following items:
- * </p>
  * <p>
  * timed_out (bool) - true if the stream
  * timed out while waiting for data on the last call to
@@ -855,13 +897,29 @@ function socket_set_blocking ($socket, $mode) {}
  * <p>
  * uri (string) - the URI/filename associated with this
  * stream.
+ * </p>
  */
-function stream_get_meta_data ($stream) {}
+#[ArrayShape([
+    "timed_out" => "bool",
+    "blocked" => "bool",
+    "eof" => "bool",
+    "unread_bytes" => "int",
+    "stream_type" => "string",
+    "wrapper_type" => "string",
+    "wrapper_data" => "mixed",
+    "mode" => "string",
+    "seekable" => "bool",
+    "uri" => "string",
+    "crypto" => "array",
+    "mediatype" => "string",
+])]
+function stream_get_meta_data ($stream): array
+{}
 
 /**
  * Gets line from stream resource up to a given delimiter
  * @link https://php.net/manual/en/function.stream-get-line.php
- * @param resource $handle <p>
+ * @param resource $stream <p>
  * A valid file handle.
  * </p>
  * @param int $length <p>
@@ -872,11 +930,12 @@ function stream_get_meta_data ($stream) {}
  * </p>
  * @return string|false a string of up to length bytes read from the file
  * pointed to by handle.
- * </p>
  * <p>
  * If an error occurs, returns false.
+ * </p>
  */
-function stream_get_line ($handle, $length, $ending = null) {}
+function stream_get_line ($stream, int $length, string $ending): string|false
+{}
 
 /**
  * Register a URL wrapper implemented as a PHP class
@@ -884,7 +943,7 @@ function stream_get_line ($handle, $length, $ending = null) {}
  * @param string $protocol <p>
  * The wrapper name to be registered.
  * </p>
- * @param string $classname <p>
+ * @param string $class <p>
  * The classname which implements the protocol.
  * </p>
  * @param int $flags [optional] <p>
@@ -893,21 +952,23 @@ function stream_get_line ($handle, $length, $ending = null) {}
  * stream.
  * </p>
  * @return bool true on success or false on failure.
- * </p>
  * <p>
  * stream_wrapper_register will return false if the
  * protocol already has a handler.
+ * </p>
  */
-function stream_wrapper_register ($protocol, $classname, $flags = null) {}
+function stream_wrapper_register (string $protocol, string $class, int $flags): bool
+{}
 
 /**
- * &Alias; <function>stream_wrapper_register</function>
- * <p>Register a URL wrapper implemented as a PHP class
+ * Alias:
+ * {@see stream_wrapper_register}
+ * <p>Register a URL wrapper implemented as a PHP class</p>
  * @link https://php.net/manual/en/function.stream-register-wrapper.php
  * @param string $protocol <p>
  * The wrapper name to be registered.
  * </p>
- * @param string $classname <p>
+ * @param string $class <p>
  * The classname which implements the protocol.
  * </p>
  * @param int $flags [optional] <p>
@@ -916,22 +977,23 @@ function stream_wrapper_register ($protocol, $classname, $flags = null) {}
  * stream.
  * </p>
  * @return bool true on success or false on failure.
- * </p>
  * <p>
  * stream_wrapper_register will return false if the
  * protocol already has a handler.
+ * </p>
  */
-function stream_register_wrapper ($protocol, $classname, $flags = 0) {}
+function stream_register_wrapper (string $protocol, string $class, int $flags = 0): bool
+{}
 
 /**
  * Resolve filename against the include path according to the same rules as fopen()/include().
  * @link https://php.net/manual/en/function.stream-resolve-include-path.php
- * @param string $filename The filename to resolve.<p>
- * </p>
+ * @param string $filename The filename to resolve.
  * @return string|false containing the resolved absolute filename, or FALSE on failure.
  * @since 5.3.2
  */
-function stream_resolve_include_path ($filename) {}
+function stream_resolve_include_path (string $filename): string|false
+{}
 
 /**
  * Unregister a URL wrapper
@@ -940,7 +1002,8 @@ function stream_resolve_include_path ($filename) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function stream_wrapper_unregister ($protocol) {}
+function stream_wrapper_unregister (string $protocol): bool
+{}
 
 /**
  * Restores a previously unregistered built-in wrapper
@@ -949,7 +1012,8 @@ function stream_wrapper_unregister ($protocol) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function stream_wrapper_restore ($protocol) {}
+function stream_wrapper_restore (string $protocol): bool
+{}
 
 /**
  * Retrieve list of registered streams
@@ -957,34 +1021,40 @@ function stream_wrapper_restore ($protocol) {}
  * @return array an indexed array containing the name of all stream wrappers
  * available on the running system.
  */
-function stream_get_wrappers () {}
+#[Pure]
+function stream_get_wrappers (): array
+{}
 
 /**
  * Retrieve list of registered socket transports
  * @link https://php.net/manual/en/function.stream-get-transports.php
  * @return array an indexed array of socket transports names.
  */
-function stream_get_transports () {}
+#[Pure]
+function stream_get_transports (): array
+{}
 
 /**
  * Checks if a stream is a local stream
  * @link https://php.net/manual/en/function.stream-is-local.php
- * @param mixed $stream_or_url <p>
+ * @param mixed $stream <p>
  * The stream resource or URL to check.
  * </p>
  * @return bool true on success or false on failure.
  * @since 5.2.4
  */
-function stream_is_local ($stream_or_url) {}
+#[Pure]
+function stream_is_local ($stream): bool
+{}
 
 /**
- * Fetches all the headers sent by the server in response to a HTTP request
+ * Fetches all the headers sent by the server in response to an HTTP request
  * @link https://php.net/manual/en/function.get-headers.php
  * @param string $url <p>
  * The target URL.
  * </p>
- * @param int $format [optional] <p>
- * If the optional format parameter is set to non-zero,
+ * @param bool $associative [optional] <p>
+ * If the optional format parameter is set to true,
  * get_headers parses the response and sets the
  * array's keys.
  * </p>
@@ -992,7 +1062,9 @@ function stream_is_local ($stream_or_url) {}
  * @return array|false an indexed or associative array with the headers, or false on
  * failure.
  */
-function get_headers ($url, $format = null, $context = null) {}
+#[Pure]
+function get_headers (string $url, bool $associative = false, $context): array|false
+{}
 
 /**
  * Set timeout period on a stream
@@ -1008,11 +1080,13 @@ function get_headers ($url, $format = null, $context = null) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function stream_set_timeout ($stream, $seconds, $microseconds = null) {}
+function stream_set_timeout ($stream, int $seconds, int $microseconds): bool
+{}
 
 /**
- * &Alias; <function>stream_set_timeout</function>
- * <p>Set timeout period on a stream
+ * Alias:
+ * {@see stream_set_timeout}
+ * Set timeout period on a stream
  * @link https://php.net/manual/en/function.socket-set-timeout.php
  * @param resource $stream <p>
  * The target stream.
@@ -1025,10 +1099,12 @@ function stream_set_timeout ($stream, $seconds, $microseconds = null) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function socket_set_timeout ($stream, $seconds, $microseconds = 0) {}
+function socket_set_timeout ($stream, int $seconds, int $microseconds = 0): bool
+{}
 
 /**
- * &Alias; <function>stream_get_meta_data</function>
+ * Alias:
+ * {@see stream_get_meta_data}
  * Retrieves header/meta data from streams/file pointers
  * @link https://php.net/manual/en/function.socket-get-status.php
  * @param resource $stream <p>
@@ -1036,7 +1112,6 @@ function socket_set_timeout ($stream, $seconds, $microseconds = 0) {}
  * fsockopen and pfsockopen.
  * </p>
  * @return array The result array contains the following items:
- * </p>
  * <p>
  * timed_out (bool) - true if the stream
  * timed out while waiting for data on the last call to
@@ -1089,8 +1164,10 @@ function socket_set_timeout ($stream, $seconds, $microseconds = 0) {}
  * <p>
  * uri (string) - the URI/filename associated with this
  * stream.
+ * </p>
  */
-function socket_get_status ($stream) {}
+function socket_get_status ($stream): array
+{}
 
 /**
  * Returns canonicalized absolute pathname
@@ -1100,12 +1177,14 @@ function socket_get_status ($stream) {}
  * </p>
  * @return string|false the canonicalized absolute pathname on success. The resulting path
  * will have no symbolic link, '/./' or '/../' components.
- * </p>
  * <p>
  * realpath returns false on failure, e.g. if
  * the file does not exist.
+ * </p>
  */
-function realpath ($path) {}
+#[Pure]
+function realpath (string $path): string|false
+{}
 
 /**
  * Match filename against a pattern
@@ -1113,7 +1192,7 @@ function realpath ($path) {}
  * @param string $pattern <p>
  * The shell wildcard pattern.
  * </p>
- * @param string $string <p>
+ * @param string $filename <p>
  * The tested string. This function is especially useful for filenames,
  * but may also be used on regular strings.
  * </p>
@@ -1163,5 +1242,6 @@ function realpath ($path) {}
  * </p>
  * @return bool true if there is a match, false otherwise.
  */
-function fnmatch ($pattern, $string, $flags = null) {}
+function fnmatch (string $pattern, string $filename, int $flags): bool
+{}
 ?>
