@@ -1,5 +1,9 @@
 <?php
 
+use JetBrains\PhpStorm\Deprecated;
+use JetBrains\PhpStorm\Internal\LanguageLevelTypeAware;
+use JetBrains\PhpStorm\Pure;
+
 
 /**
  * Generate a system log message
@@ -55,14 +59,16 @@
  * </p>
  * @return bool true on success or false on failure.
  */
-function syslog ($priority, $message) {}
+function syslog (int $priority, string $message): bool
+{}
 
 /**
  * Close connection to system logger
  * @link https://php.net/manual/en/function.closelog.php
  * @return bool true on success or false on failure.
  */
-function closelog () {}
+function closelog (): bool
+{}
 
 /**
  * Registers a function that will be called when PHP starts sending output.
@@ -72,14 +78,15 @@ function closelog () {}
  * @param callable $callback Function called just before the headers are sent.
  * @return bool true on success or false on failure.
  */
-function header_register_callback ( callable $callback ) {}
+function header_register_callback ( callable $callback ): bool
+{}
 
 /**
- * PHP > 5.4.0<br/>
  * Get the size of an image from a string.
+ * @since 5.4
  * @link https://secure.php.net/manual/en/function.getimagesizefromstring.php
- * @param string $imagedata The image data, as a string.
- * @param array &$imageinfo This optional parameter allows you to extract<br>
+ * @param string $string The image data, as a string.
+ * @param array &$image_info [optional] This optional parameter allows you to extract<br>
  * some extended information from the image file. Currently, this will <br>
  * return the different JPG APP markers as an associative array. <br>
  * Some programs use these APP markers to embed text information in images. <br>
@@ -91,27 +98,32 @@ function header_register_callback ( callable $callback ) {}
  * Index 3 is a text string with the correct <b>height="yyy" width="xxx"</b> string<br>
  * that can be used directly in an IMG tag.<br>
  * On failure, FALSE is returned.
+ * @link https://secure.php.net/manual/en/function.getimagesizefromstring.php
+ * @since 5.4
  */
-function getimagesizefromstring ($imagedata , array &$imageinfo = null) {}
+function getimagesizefromstring (string $string , &$image_info): array|false
+{}
 
 /**
- * PHP > 5.4.0<br/>
  * Set the stream chunk size.
- * @link https://secure.php.net/manual/en/function.stream-set-chunk-size.php
- * @param resource $fp The target stream.
- * @param int $chunk_size The desired new chunk size.
+ * @param resource $stream The target stream.
+ * @param int $size The desired new chunk size.
  * @return int|false Returns the previous chunk size on success.<br>
  * Will return <b>FALSE</b> if chunk_size is less than 1 or greater than <b>PHP_INT_MAX</b>.
+ * @link https://secure.php.net/manual/en/function.stream-set-chunk-size.php
+ * @since 5.4
  */
-function stream_set_chunk_size ($fp , $chunk_size) {}
+#[LanguageLevelTypeAware(["8.0" => "int"], default: "int|false")]
+function stream_set_chunk_size ($stream , int $size)
+{}
 
 /**
  * Initializes all syslog related variables
  * @link https://php.net/manual/en/function.define-syslog-variables.php
- * @deprecated 5.3
  * @return void
  * @removed 5.4
  */
+#[Deprecated(since: '5.3')]
 function define_syslog_variables () {}
 
 /**
@@ -119,26 +131,30 @@ function define_syslog_variables () {}
  * @link https://php.net/manual/en/function.lcg-value.php
  * @return float A pseudo random float value in the range of (0, 1)
  */
-function lcg_value () {}
+function lcg_value (): float
+{}
 
 /**
  * Calculate the metaphone key of a string
  * @link https://php.net/manual/en/function.metaphone.php
- * @param string $str <p>
+ * @param string $string <p>
  * The input string.
  * </p>
- * @param int $phonemes [optional] <p>
+ * @param int $max_phonemes [optional] <p>
  * This parameter restricts the returned metaphone key to phonemes characters in length.
  * The default value of 0 means no restriction.
  * </p>
  * @return string|false the metaphone key as a string, or FALSE on failure
  */
-function metaphone ($str, $phonemes = 0) {}
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "string"], default: "string|false")]
+function metaphone (string $string, int $max_phonemes = 0): bool|string
+{}
 
 /**
  * Turn on output buffering
  * @link https://php.net/manual/en/function.ob-start.php
- * @param callback $output_callback [optional] <p>
+ * @param callback $callback [optional] <p>
  * An optional output_callback function may be
  * specified. This function takes a string as a parameter and should
  * return a string. The function will be called when
@@ -200,21 +216,22 @@ function metaphone ($str, $phonemes = 0) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function ob_start ($output_callback = null, $chunk_size = null, $flags = PHP_OUTPUT_HANDLER_STDFLAGS) {}
+function ob_start ($callback, int $chunk_size, int $flags = PHP_OUTPUT_HANDLER_STDFLAGS): bool
+{}
 
 /**
  * Flush (send) the output buffer
  * @link https://php.net/manual/en/function.ob-flush.php
- * @return void
+ * @return bool
  */
-function ob_flush () {}
+function ob_flush (): bool {}
 
 /**
  * Clean (erase) the output buffer
  * @link https://php.net/manual/en/function.ob-clean.php
- * @return void
+ * @return bool
  */
-function ob_clean () {}
+function ob_clean (): bool {}
 
 /**
  * Flush (send) the output buffer and turn off output buffering
@@ -223,7 +240,8 @@ function ob_clean () {}
  * function without an active buffer or that for some reason a buffer could
  * not be deleted (possible for special buffer).
  */
-function ob_end_flush () {}
+function ob_end_flush (): bool
+{}
 
 /**
  * Clean (erase) the output buffer and turn off output buffering
@@ -232,14 +250,16 @@ function ob_end_flush () {}
  * function without an active buffer or that for some reason a buffer could
  * not be deleted (possible for special buffer).
  */
-function ob_end_clean () {}
+function ob_end_clean (): bool
+{}
 
 /**
  * Flush the output buffer, return it as a string and turn off output buffering
  * @link https://php.net/manual/en/function.ob-get-flush.php
  * @return string|false the output buffer or false if no buffering is active.
  */
-function ob_get_flush () {}
+function ob_get_flush (): string|false
+{}
 
 /**
  * Get current buffer contents and delete current output buffer
@@ -247,7 +267,8 @@ function ob_get_flush () {}
  * @return string|false the contents of the output buffer and end output buffering.
  * If output buffering isn't active then false is returned.
  */
-function ob_get_clean () {}
+function ob_get_clean (): string|false
+{}
 
 /**
  * Return the length of the output buffer
@@ -255,7 +276,8 @@ function ob_get_clean () {}
  * @return int|false the length of the output buffer contents or false if no
  * buffering is active.
  */
-function ob_get_length () {}
+function ob_get_length (): int|false
+{}
 
 /**
  * Return the nesting level of the output buffering mechanism
@@ -263,7 +285,8 @@ function ob_get_length () {}
  * @return int the level of nested output buffering handlers or zero if output
  * buffering is not active.
  */
-function ob_get_level () {}
+function ob_get_level (): int
+{}
 
 /**
  * Get status of output buffers
@@ -334,7 +357,8 @@ function ob_get_level () {}
  * <tr><td>blocksize</td><td>...</td></tr>
  * </table>
  */
-function ob_get_status ($full_status = null) {}
+function ob_get_status (bool $full_status): array
+{}
 
 /**
  * Return the contents of the output buffer
@@ -342,17 +366,19 @@ function ob_get_status ($full_status = null) {}
  * @return string|false This will return the contents of the output buffer or false, if output
  * buffering isn't active.
  */
-function ob_get_contents () {}
+function ob_get_contents (): string|false
+{}
 
 /**
  * Turn implicit flush on/off
  * @link https://php.net/manual/en/function.ob-implicit-flush.php
- * @param int $flag [optional] <p>
- * 1 to turn implicit flushing on, 0 otherwise.
+ * @param int|bool $enable [optional] <p>
+ * 1|<b>TRUE</b> to turn implicit flushing on, 0|<b>FALSE</b> turns it off.
+ * <br><br>default: 1|<b>TRUE</b>
  * </p>
  * @return void
  */
-function ob_implicit_flush ($flag = 1) {}
+function ob_implicit_flush (#[LanguageLevelTypeAware(["8.0" => "bool"], default: "int")] $enable): void {}
 
 /**
  * List all output handlers in use
@@ -363,7 +389,8 @@ function ob_implicit_flush ($flag = 1) {}
  * ob_list_handlers will return "default output
  * handler".
  */
-function ob_list_handlers () {}
+function ob_list_handlers (): array
+{}
 
 /**
  * Sort an array by key
@@ -371,14 +398,15 @@ function ob_list_handlers () {}
  * @param array &$array <p>
  * The input array.
  * </p>
- * @param int $sort_flags [optional] <p>
+ * @param int $flags [optional] <p>
  * You may modify the behavior of the sort using the optional
  * parameter sort_flags, for details
  * see sort.
  * </p>
  * @return bool true on success or false on failure.
  */
-function ksort (array &$array, $sort_flags = null) {}
+function ksort (array &$array, int $flags): bool
+{}
 
 /**
  * Sort an array by key in reverse order
@@ -386,14 +414,15 @@ function ksort (array &$array, $sort_flags = null) {}
  * @param array &$array <p>
  * The input array.
  * </p>
- * @param int $sort_flags [optional] <p>
+ * @param int $flags [optional] <p>
  * You may modify the behavior of the sort using the optional parameter
  * sort_flags, for details see
  * sort.
  * </p>
  * @return bool true on success or false on failure.
  */
-function krsort (array &$array, $sort_flags = null) {}
+function krsort (array &$array, int $flags): bool
+{}
 
 /**
  * Sort an array using a "natural order" algorithm
@@ -403,7 +432,8 @@ function krsort (array &$array, $sort_flags = null) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function natsort (array &$array) {}
+function natsort (array &$array): bool
+{}
 
 /**
  * Sort an array using a case insensitive "natural order" algorithm
@@ -413,7 +443,8 @@ function natsort (array &$array) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function natcasesort (array &$array) {}
+function natcasesort (array &$array): bool
+{}
 
 /**
  * Sort an array and maintain index association
@@ -421,14 +452,15 @@ function natcasesort (array &$array) {}
  * @param array &$array <p>
  * The input array.
  * </p>
- * @param int $sort_flags [optional] <p>
+ * @param int $flags [optional] <p>
  * You may modify the behavior of the sort using the optional
  * parameter sort_flags, for details
  * see sort.
  * </p>
  * @return bool true on success or false on failure.
  */
-function asort (array &$array, $sort_flags = null) {}
+function asort (array &$array, int $flags): bool
+{}
 
 /**
  * Sort an array in reverse order and maintain index association
@@ -436,14 +468,15 @@ function asort (array &$array, $sort_flags = null) {}
  * @param array &$array <p>
  * The input array.
  * </p>
- * @param int $sort_flags [optional] <p>
+ * @param int $flags [optional] <p>
  * You may modify the behavior of the sort using the optional parameter
  * sort_flags, for details see
  * sort.
  * </p>
  * @return bool true on success or false on failure.
  */
-function arsort (array &$array, $sort_flags = null) {}
+function arsort (array &$array, int $flags): bool
+{}
 
 /**
  * Sort an array
@@ -451,17 +484,18 @@ function arsort (array &$array, $sort_flags = null) {}
  * @param array &$array <p>
  * The input array.
  * </p>
- * @param int $sort_flags [optional] <p>
+ * @param int $flags [optional] <p>
  * The optional second parameter sort_flags
- * may be used to modify the sorting behavior using these values:
+ * may be used to modify the sorting behavior using these values.
  * </p>
  * <p>
- * Sorting type flags:
+ * Sorting type flags:<br>
  * SORT_REGULAR - compare items normally
- * (don't change types)
+ * (don't change types)</p>
  * @return bool true on success or false on failure.
  */
-function sort (array &$array, $sort_flags = null) {}
+function sort (array &$array, int $flags): bool
+{}
 
 /**
  * Sort an array in reverse order
@@ -469,14 +503,15 @@ function sort (array &$array, $sort_flags = null) {}
  * @param array &$array <p>
  * The input array.
  * </p>
- * @param int $sort_flags [optional] <p>
+ * @param int $flags [optional] <p>
  * You may modify the behavior of the sort using the optional
  * parameter sort_flags, for details see
  * sort.
  * </p>
  * @return bool true on success or false on failure.
  */
-function rsort (array &$array, $sort_flags = null) {}
+function rsort (array &$array, int $flags): bool
+{}
 
 /**
  * Sort an array by values using a user-defined comparison function
@@ -484,14 +519,15 @@ function rsort (array &$array, $sort_flags = null) {}
  * @param array &$array <p>
  * The input array.
  * </p>
- * @param callback $cmp_function <p>
+ * @param callback $callback <p>
  * The comparison function must return an integer less than, equal to, or
  * greater than zero if the first argument is considered to be
  * respectively less than, equal to, or greater than the second.
  * </p>
  * @return bool true on success or false on failure.
  */
-function usort (array &$array, $cmp_function) {}
+function usort (array &$array, callable $callback): bool
+{}
 
 /**
  * Sort an array with a user-defined comparison function and maintain index association
@@ -499,13 +535,14 @@ function usort (array &$array, $cmp_function) {}
  * @param array &$array <p>
  * The input array.
  * </p>
- * @param callback $cmp_function <p>
+ * @param callback $callback <p>
  * See usort and uksort for
  * examples of user-defined comparison functions.
  * </p>
  * @return bool true on success or false on failure.
  */
-function uasort (array &$array, $cmp_function) {}
+function uasort (array &$array, callable $callback): bool
+{}
 
 /**
  * Sort an array by keys using a user-defined comparison function
@@ -513,7 +550,7 @@ function uasort (array &$array, $cmp_function) {}
  * @param array &$array <p>
  * The input array.
  * </p>
- * @param callback $cmp_function <p>
+ * @param callback $callback <p>
  * The callback comparison function.
  * </p>
  * <p>
@@ -526,7 +563,8 @@ function uasort (array &$array, $cmp_function) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function uksort (array &$array, $cmp_function) {}
+function uksort (array &$array, callable $callback): bool
+{}
 
 /**
  * Shuffle an array
@@ -536,15 +574,16 @@ function uksort (array &$array, $cmp_function) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function shuffle (array &$array) {}
+function shuffle (array &$array): bool
+{}
 
 /**
  * Apply a user function to every member of an array
  * @link https://php.net/manual/en/function.array-walk.php
- * @param array|ArrayObject &$array <p>
+ * @param array|object &$array <p>
  * The input array.
  * </p>
- * @param callback $funcname <p>
+ * @param callback $callback <p>
  * Typically, funcname takes on two parameters.
  * The array parameter's value being the first, and
  * the key/index second.
@@ -563,22 +602,23 @@ function shuffle (array &$array) {}
  * the array that array_walk is applied to is
  * changed, the behavior of this function is undefined, and unpredictable.
  * </p>
- * @param mixed $userdata [optional] <p>
+ * @param mixed $arg [optional] <p>
  * If the optional userdata parameter is supplied,
  * it will be passed as the third parameter to the callback
  * funcname.
  * </p>
  * @return bool true on success or false on failure.
  */
-function array_walk (array &$array, $funcname, $userdata = null) {}
+function array_walk (object|array &$array, callable $callback, mixed $arg): bool
+{}
 
 /**
  * Apply a user function recursively to every member of an array
  * @link https://php.net/manual/en/function.array-walk-recursive.php
- * @param array|ArrayObject &$input <p>
+ * @param array|object &$array <p>
  * The input array.
  * </p>
- * @param callback $funcname <p>
+ * @param callback $callback <p>
  * Typically, funcname takes on two parameters.
  * The input parameter's value being the first, and
  * the key/index second.
@@ -591,22 +631,23 @@ function array_walk (array &$array, $funcname, $userdata = null) {}
  * any changes made to those elements will be made in the
  * original array itself.
  * </p>
- * @param mixed $userdata [optional] <p>
+ * @param mixed $arg [optional] <p>
  * If the optional userdata parameter is supplied,
  * it will be passed as the third parameter to the callback
  * funcname.
  * </p>
  * @return bool true on success or false on failure.
  */
-function array_walk_recursive (array &$input, $funcname, $userdata = null) {}
+function array_walk_recursive (object|array &$array, callable $callback, mixed $arg): bool
+{}
 
 /**
  * Counts all elements in an array, or something in an object.
  * <p>For objects, if you have SPL installed, you can hook into count() by implementing interface {@see Countable}.
  * The interface has exactly one method, {@see Countable::count()}, which returns the return value for the count() function.
- * Please see the {@see Array} section of the manual for a detailed explanation of how arrays are implemented and used in PHP.
+ * Please see the {@see Array} section of the manual for a detailed explanation of how arrays are implemented and used in PHP.</p>
  * @link https://php.net/manual/en/function.count.php
- * @param array|Countable $var  The array or the object.
+ * @param array|Countable $value The array or the object.
  * @param int $mode [optional] If the optional mode parameter is set to
  * COUNT_RECURSIVE (or 1), count
  * will recursively count the array. This is particularly useful for
@@ -614,7 +655,6 @@ function array_walk_recursive (array &$input, $funcname, $userdata = null) {}
  * @return int the number of elements in var, which is
  * typically an array, since anything else will have one
  * element.
- * </p>
  * <p>
  * If var is not an array or an object with
  * implemented Countable interface,
@@ -626,13 +666,16 @@ function array_walk_recursive (array &$input, $funcname, $userdata = null) {}
  * Caution: count may return 0 for a variable that isn't set,
  * but it may also return 0 for a variable that has been initialized with an
  * empty array. Use isset to test if a variable is set.
+ * </p>
  */
-function count ($var, $mode = COUNT_NORMAL) {}
+#[Pure]
+function count (Countable|array $value, int $mode = COUNT_NORMAL): int
+{}
 
 /**
  * Set the internal pointer of an array to its last element
  * @link https://php.net/manual/en/function.end.php
- * @param array &$array <p>
+ * @param array|object &$array <p>
  * The array. This array is passed by reference because it is modified by
  * the function. This means you must pass it a real variable and not
  * a function returning an array because only actual variables may be
@@ -641,64 +684,65 @@ function count ($var, $mode = COUNT_NORMAL) {}
  * @return mixed|false the value of the last element or false for empty array.
  * @meta
  */
-function end (array &$array) {}
+function end (object|array &$array): mixed {}
 
 /**
  * Rewind the internal array pointer
  * @link https://php.net/manual/en/function.prev.php
- * @param array &$array <p>
+ * @param array|object &$array <p>
  * The input array.
  * </p>
- * @return mixed the array value in the previous place that's pointed to by
+ * @return mixed|false the array value in the previous place that's pointed to by
  * the internal array pointer, or false if there are no more
  * elements.
  * @meta
  */
-function prev (array &$array) {}
+function prev (object|array &$array): mixed {}
 
 /**
  * Advance the internal array pointer of an array
  * @link https://php.net/manual/en/function.next.php
- * @param array &$array <p>
+ * @param array|object &$array <p>
  * The array being affected.
  * </p>
- * @return mixed the array value in the next place that's pointed to by the
+ * @return mixed|false the array value in the next place that's pointed to by the
  * internal array pointer, or false if there are no more elements.
  * @meta
  */
-function next (array &$array) {}
+function next (object|array &$array): mixed {}
 
 /**
  * Set the internal pointer of an array to its first element
  * @link https://php.net/manual/en/function.reset.php
- * @param array &$array <p>
+ * @param array|object &$array <p>
  * The input array.
  * </p>
  * @return mixed|false the value of the first array element, or false if the array is
  * empty.
  * @meta
  */
-function reset (array &$array) {}
+function reset (object|array &$array): mixed {}
 
 /**
  * Return the current element in an array
  * @link https://php.net/manual/en/function.current.php
- * @param array $array <p>
+ * @param array|object $array <p>
  * The array.
  * </p>
- * @return mixed The current function simply returns the
+ * @return mixed|false The current function simply returns the
  * value of the array element that's currently being pointed to by the
  * internal pointer. It does not move the pointer in any way. If the
  * internal pointer points beyond the end of the elements list or the array is
  * empty, current returns false.
  * @meta
  */
-function current (array $array) {}
+#[Pure]
+function current (object|array $array): mixed {}
 
 /**
  * Fetch a key from an array
  * @link https://php.net/manual/en/function.key.php
- * @param array $array <p>
+ * @param array|object $array <p>
  * The array.
  * </p>
  * @return int|string|null The key function simply returns the
@@ -707,31 +751,33 @@ function current (array $array) {}
  * internal pointer points beyond the end of the elements list or the array is
  * empty, key returns null.
  */
-function key (array $array) {}
+#[Pure]
+function key (object|array $array): string|int|null
+{}
 
 /**
  * Find lowest value
  * @link https://php.net/manual/en/function.min.php
- * @param array|mixed $value1 Array to look through or first value to compare
- * @param mixed $value2 [optional] second value to compare
- * </p>
+ * @param array|mixed $value Array to look through or first value to compare
  * @param mixed ...$values [optional] any comparable value
  * @return mixed min returns the numerically lowest of the
  * parameter values.
  */
-function min ($value1, $value2 = null, ...$values) {}
+#[Pure]
+function min (mixed $value, mixed ...$values): mixed
+{}
 
 /**
  * Find highest value
  * @link https://php.net/manual/en/function.max.php
- * @param array|mixed $value1 Array to look through or first value to compare
- * @param mixed $value2 [optional] second value to compare
- * </p>
+ * @param array|mixed $value Array to look through or first value to compare
  * @param mixed ...$values [optional] any comparable value
  * @return mixed max returns the numerically highest of the
  * parameter values, either within a arg array or two arguments.
  */
-function max ($value1, $value2 = null, ...$values) {}
+#[Pure]
+function max (mixed $value, mixed ...$values): mixed
+{}
 
 /**
  * Checks if a value exists in an array
@@ -755,10 +801,12 @@ function max ($value1, $value2 = null, ...$values) {}
  * @return bool true if needle is found in the array,
  * false otherwise.
  */
-function in_array ($needle, array $haystack, $strict = false) {}
+#[Pure]
+function in_array (mixed $needle, array $haystack, bool $strict = false): bool
+{}
 
 /**
- * Searches the array for a given value and returns the corresponding key if successful
+ * Searches the array for a given value and returns the first corresponding key if successful
  * @link https://php.net/manual/en/function.array-search.php
  * @param mixed $needle <p>
  * The searched value.
@@ -785,12 +833,14 @@ function in_array ($needle, array $haystack, $strict = false) {}
  * all matching values, use array_keys with the optional
  * search_value parameter instead.
  */
-function array_search ($needle, array $haystack, $strict = null) {}
+#[Pure]
+function array_search (mixed $needle, array $haystack, bool $strict): string|int|false
+{}
 
 /**
  * Import variables into the current symbol table from an array
  * @link https://php.net/manual/en/function.extract.php
- * @param array $var_array<p>
+ * @param array &$array<p>
  * Note that prefix is only required if
  * extract_type is EXTR_PREFIX_SAME,
  * EXTR_PREFIX_ALL, EXTR_PREFIX_INVALID
@@ -799,36 +849,39 @@ function array_search ($needle, array $haystack, $strict = null) {}
  * imported into the symbol table. Prefixes are automatically separated from
  * the array key by an underscore character.
  * </p>
- * @param int $extract_type [optional] <p>
+ * @param int $flags [optional] <p>
  * The way invalid/numeric keys and collisions are treated is determined
  * by the extract_type. It can be one of the
  * following values:
  * EXTR_OVERWRITE
- * If there is a collision, overwrite the existing variable.
- * @param string $prefix [optional] Only overwrite the variable if it already exists in the
+ * If there is a collision, overwrite the existing variable.</p>
+ * @param string $prefix [optional] <p>Only overwrite the variable if it already exists in the
  * current symbol table, otherwise do nothing. This is useful
  * for defining a list of valid variables and then extracting
  * only those variables you have defined out of
- * $_REQUEST, for example.
+ * $_REQUEST, for example.</p>
  * @return int the number of variables successfully imported into the symbol
  * table.
  */
-function extract (array $var_array, $extract_type = null, $prefix = null) {}
+function extract (array &$array, int $flags, string $prefix): int
+{}
 
 /**
  * Create array containing variables and their values
  * @link https://php.net/manual/en/function.compact.php
- * @param mixed $varname <p>
+ * @param mixed $var_name <p>
  * compact takes a variable number of parameters.
  * Each parameter can be either a string containing the name of the
  * variable, or an array of variable names. The array can contain other
  * arrays of variable names inside it; compact
  * handles it recursively.
  * </p>
- * @param mixed ...$_ [optional]
+ * @param mixed ...$var_names [optional]
  * @return array the output array with all the variables added to it.
  */
-function compact ($varname, ...$_) {}
+#[Pure]
+function compact (mixed $var_name, ...$var_names): array
+{}
 
 /**
  * Fill an array with values
@@ -837,7 +890,7 @@ function compact ($varname, ...$_) {}
  * The first index of the returned array.
  * Supports non-negative indexes only.
  * </p>
- * @param int $num <p>
+ * @param int $count <p>
  * Number of elements to insert
  * </p>
  * @param mixed $value <p>
@@ -845,7 +898,9 @@ function compact ($varname, ...$_) {}
  * </p>
  * @return array the filled array
  */
-function array_fill ($start_index, $num, $value) {}
+#[Pure]
+function array_fill (int $start_index, int $count, mixed $value): array
+{}
 
 /**
  * Fill an array with values, specifying keys
@@ -859,7 +914,9 @@ function array_fill ($start_index, $num, $value) {}
  * </p>
  * @return array the filled array
  */
-function array_fill_keys (array $keys, $value) {}
+#[Pure]
+function array_fill_keys (array $keys, mixed $value): array
+{}
 
 /**
  * Create an array containing a range of elements
@@ -879,38 +936,26 @@ function array_fill_keys (array $keys, $value) {}
  * @return array an array of elements from start to
  * end, inclusive.
  */
-function range ($start, $end, $step = 1) {}
+#[Pure]
+function range ($start, $end, int|float $step = 1): array
+{}
 
 /**
  * Sort multiple or multi-dimensional arrays
  * @link https://php.net/manual/en/function.array-multisort.php
- * @param array &$array1 <p>
+ * @param array &$array <p>
  * An array being sorted.
  * </p>
- * @param array|int $array1_sort_order [optional] <p>
- * The order used to sort the previous array argument.
- * Either SORT_ASC to sort ascendingly or SORT_DESC to sort descendingly.
- * This argument can be swapped with array1_sort_flags or omitted entirely, in which case SORT_ASC is assumed.
- * </p>
- * @param array|int $array1_sort_flags [optional] <p>
- * Sort options for the previous array argument:
- * Sorting type flags:
- * SORT_REGULAR - compare items normally (don't change types)
- * SORT_NUMERIC - compare items numerically
- * SORT_STRING - compare items as strings
- * SORT_LOCALE_STRING - compare items as strings, based on the current locale. It uses the locale, which can be changed using setlocale()
- * SORT_NATURAL - compare items as strings using "natural ordering" like natsort()
- * SORT_FLAG_CASE - can be combined (bitwise OR) with SORT_STRING or SORT_NATURAL to sort strings case-insensitively
- * This argument can be swapped with array1_sort_order or omitted entirely, in which case SORT_REGULAR is assumed.
- * </p>
- * @param array|int &...$_ [optional] <p>
+ * @param  &...$rest [optional] <p>
  * More arrays, optionally followed by sort order and flags.
  * Only elements corresponding to equivalent elements in previous arrays are compared.
  * In other words, the sort is lexicographical.
  * </p>
  * @return bool true on success or false on failure.
  */
-function array_multisort (array &$array1, $array1_sort_order = null, $array1_sort_flags = null, ...$_) {}
+function array_multisort (&$array, &...$rest): bool
+{}
+
 
 /**
  * Push elements onto the end of array
@@ -920,12 +965,13 @@ function array_multisort (array &$array1, $array1_sort_order = null, $array1_sor
  * @param array &$array <p>
  * The input array.
  * </p>
- * @param mixed ...$vars [optional] <p>
+ * @param mixed ...$values [optional] <p>
  * The pushed variables.
  * </p>
  * @return int the number of elements in the array.
  */
-function array_push (array &$array, ...$vars) {}
+function array_push (array &$array, ...$values): int
+{}
 
 /**
  * Pop the element off the end of array
@@ -933,12 +979,12 @@ function array_push (array &$array, ...$vars) {}
  * @param array &$array <p>
  * The array to get the value from.
  * </p>
- * @return mixed the last value of array.
+ * @return mixed|null the last value of array.
  * If array is empty (or is not an array),
  * null will be returned.
  * @meta
  */
-function array_pop (array &$array) {}
+function array_pop (array &$array): mixed {}
 
 /**
  * Shift an element off the beginning of array
@@ -946,11 +992,11 @@ function array_pop (array &$array) {}
  * @param array &$array <p>
  * The input array.
  * </p>
- * @return mixed the shifted value, or null if array is
+ * @return mixed|null the shifted value, or null if array is
  * empty or is not an array.
  * @meta
  */
-function array_shift (array &$array) {}
+function array_shift (array &$array): mixed {}
 
 /**
  * Prepend elements to the beginning of an array
@@ -960,17 +1006,18 @@ function array_shift (array &$array) {}
  * @param array &$array <p>
  * The input array.
  * </p>
- * @param mixed ...$vars [optional] <p>
+ * @param mixed ...$values [optional] <p>
  * The prepended variables.
  * </p>
  * @return int the number of elements in the array.
  */
-function array_unshift (array &$array, ...$vars) {}
+function array_unshift (array &$array, ...$values): int
+{}
 
 /**
  * Remove a portion of the array and replace it with something else
  * @link https://php.net/manual/en/function.array-splice.php
- * @param array &$input <p>
+ * @param array &$array <p>
  * The input array.
  * </p>
  * @param int $offset <p>
@@ -980,7 +1027,7 @@ function array_unshift (array &$array, ...$vars) {}
  * is negative then it starts that far from the end of the
  * input array.
  * </p>
- * @param int $length [optional] <p>
+ * @param int|null $length [optional] <p>
  * If length is omitted, removes everything
  * from offset to the end of the array. If
  * length is specified and is positive, then
@@ -1011,7 +1058,8 @@ function array_unshift (array &$array, ...$vars) {}
  * </p>
  * @return array the array consisting of the extracted elements.
  */
-function array_splice (array &$input, $offset, $length = null, $replacement = null) {}
+function array_splice (array &$array, int $offset, ?int $length, mixed $replacement): array
+{}
 
 /**
  * Extract a slice of the array
@@ -1025,7 +1073,7 @@ function array_splice (array &$input, $offset, $length = null, $replacement = nu
  * offset is negative, the sequence will
  * start that far from the end of the array.
  * </p>
- * @param int $length [optional] <p>
+ * @param int|null $length [optional] <p>
  * If length is given and is positive, then
  * the sequence will have that many elements in it. If
  * length is given and is negative then the
@@ -1042,7 +1090,9 @@ function array_splice (array &$input, $offset, $length = null, $replacement = nu
  * @return array the slice.
  * @meta
  */
-function array_slice (array $array, $offset, $length = null, $preserve_keys = false) {}
+#[Pure]
+function array_slice (array $array, int $offset, ?int $length, bool $preserve_keys = false): array
+{}
 
 /**
  * Merge one or more arrays
@@ -1051,5 +1101,8 @@ function array_slice (array $array, $offset, $length = null, $preserve_keys = fa
  * Initial array to merge.
  * </p>
  * @return array the resulting array.
+ * @meta
  */
-function array_merge (array ...$arrays) {}
+#[Pure]
+function array_merge (array ...$arrays): array
+{}
