@@ -10,17 +10,17 @@ use function is_string;
 class PHPDefineConstant extends PHPConst
 {
     /**
-     * @param array $constant
-     * @return $this
+     * @param array $reflectionObject
+     * @return static
      */
-    public function readObjectFromReflection($constant): self
+    public function readObjectFromReflection($reflectionObject): static
     {
-        if (is_string($constant[0])) {
-            $this->name = utf8_encode($constant[0]);
+        if (is_string($reflectionObject[0])) {
+            $this->name = utf8_encode($reflectionObject[0]);
         } else {
-            $this->name = $constant[0];
+            $this->name = $reflectionObject[0];
         }
-        $constantValue = $constant[1];
+        $constantValue = $reflectionObject[1];
         if ($constantValue !== null) {
             if (is_resource($constantValue)) {
                 $this->value = 'PHPSTORM_RESOURCE';
@@ -37,9 +37,9 @@ class PHPDefineConstant extends PHPConst
 
     /**
      * @param FuncCall $node
-     * @return $this
+     * @return static
      */
-    public function readObjectFromStubNode($node): self
+    public function readObjectFromStubNode($node): static
     {
         $constName = $this->getConstantFQN($node, $node->args[0]->value->value);
         if (in_array($constName, ['null', 'true', 'false'])) {
