@@ -1,11 +1,13 @@
 <?php
 
 // Start of xml v.
+use JetBrains\PhpStorm\Internal\LanguageLevelTypeAware;
+use JetBrains\PhpStorm\Pure;
 
 /**
  * Create an XML parser
  * @link https://php.net/manual/en/function.xml-parser-create.php
- * @param string $encoding [optional] <p>
+ * @param string|null $encoding [optional] <p>
  * The optional <i>encoding</i> specifies the character
  * encoding for the input/output in PHP 4. Starting from PHP 5, the input
  * encoding is automatically detected, so that the
@@ -18,14 +20,16 @@
  * encodings are ISO-8859-1, UTF-8 and
  * US-ASCII.
  * </p>
- * @return resource a resource handle for the new XML parser.
+ * @return resource|false|XMLParser a resource handle for the new XML parser.
  */
-function xml_parser_create ($encoding = null) {}
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")]
+function xml_parser_create (?string $encoding) {}
 
 /**
  * Create an XML parser with namespace support
  * @link https://php.net/manual/en/function.xml-parser-create-ns.php
- * @param string $encoding [optional] <p>
+ * @param string|null $encoding [optional] <p>
  * The optional <i>encoding</i> specifies the character
  * encoding for the input/output in PHP 4. Starting from PHP 5, the input
  * encoding is automatically detected, so that the
@@ -41,14 +45,16 @@ function xml_parser_create ($encoding = null) {}
  * handler functions will consist of namespace and tag name separated by
  * the string specified in <i>separator</i>.
  * </p>
- * @return resource a resource handle for the new XML parser.
+ * @return resource|false|XMLParser a resource handle for the new XML parser.
  */
-function xml_parser_create_ns ($encoding = null, $separator = ':') {}
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")]
+function xml_parser_create_ns (?string $encoding, string $separator = ':') {}
 
 /**
  * Use XML Parser within an object
  * @link https://php.net/manual/en/function.xml-set-object.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser to use inside the object.
  * </p>
  * @param object $object <p>
@@ -56,15 +62,16 @@ function xml_parser_create_ns ($encoding = null, $separator = ':') {}
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function xml_set_object ($parser, &$object) {}
+function xml_set_object (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser, object $object): bool
+{}
 
 /**
  * Set up start and end element handlers
  * @link https://php.net/manual/en/function.xml-set-element-handler.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser to set up start and end element handler functions.
  * </p>
- * @param callable $start_element_handler <p>
+ * @param callable $start_handler <p>
  * The function named by <i>start_element_handler</i>
  * must accept three parameters:
  * <b>start_element_handler</b>
@@ -73,8 +80,8 @@ function xml_set_object ($parser, &$object) {}
  * <b>array<i>attribs</i></b>
  * <i>parser</i>
  * The first parameter, parser, is a
- * reference to the XML parser calling the handler.
- * @param callable $end_element_handler <p>
+ * reference to the XML parser calling the handler.</p>
+ * @param callable $end_handler <p>
  * The function named by <i>end_element_handler</i>
  * must accept two parameters:
  * <b>end_element_handler</b>
@@ -82,15 +89,15 @@ function xml_set_object ($parser, &$object) {}
  * <b>string<i>name</i></b>
  * <i>parser</i>
  * The first parameter, parser, is a
- * reference to the XML parser calling the handler.
+ * reference to the XML parser calling the handler.</p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function xml_set_element_handler ($parser, callable $start_element_handler, callable $end_element_handler) {}
+function xml_set_element_handler (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser, $start_handler, $end_handler): bool {}
 
 /**
  * Set up character data handler
  * @link https://php.net/manual/en/function.xml-set-character-data-handler.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser to set up character data handler function.
  * </p>
  * @param callable $handler <p>
@@ -106,15 +113,15 @@ function xml_set_element_handler ($parser, callable $start_element_handler, call
  * <b>string<i>data</i></b>
  * <i>parser</i>
  * The first parameter, parser, is a
- * reference to the XML parser calling the handler.
+ * reference to the XML parser calling the handler.</p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function xml_set_character_data_handler ($parser, callable $handler) {}
+function xml_set_character_data_handler (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser, $handler): bool {}
 
 /**
  * Set up processing instruction (PI) handler
  * @link https://php.net/manual/en/function.xml-set-processing-instruction-handler.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser to set up processing instruction (PI) handler function.
  * </p>
  * @param callable $handler <p>
@@ -131,15 +138,15 @@ function xml_set_character_data_handler ($parser, callable $handler) {}
  * <b>string<i>data</i></b>
  * <i>parser</i>
  * The first parameter, parser, is a
- * reference to the XML parser calling the handler.
+ * reference to the XML parser calling the handler.</p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function xml_set_processing_instruction_handler ($parser, callable $handler) {}
+function xml_set_processing_instruction_handler (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser, $handler): bool {}
 
 /**
  * Set up default handler
  * @link https://php.net/manual/en/function.xml-set-default-handler.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser to set up default handler function.
  * </p>
  * @param callable $handler <p>
@@ -155,15 +162,15 @@ function xml_set_processing_instruction_handler ($parser, callable $handler) {}
  * <b>string<i>data</i></b>
  * <i>parser</i>
  * The first parameter, parser, is a
- * reference to the XML parser calling the handler.
+ * reference to the XML parser calling the handler.</p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function xml_set_default_handler ($parser, callable $handler) {}
+function xml_set_default_handler (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser, $handler): bool {}
 
 /**
  * Set up unparsed entity declaration handler
  * @link https://php.net/manual/en/function.xml-set-unparsed-entity-decl-handler.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser to set up unparsed entity declaration handler function.
  * </p>
  * @param callable $handler <p>
@@ -184,15 +191,15 @@ function xml_set_default_handler ($parser, callable $handler) {}
  * <i>parser</i>
  * The first parameter, parser, is a
  * reference to the XML parser calling the
- * handler.
+ * handler.</p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function xml_set_unparsed_entity_decl_handler ($parser, callable $handler) {}
+function xml_set_unparsed_entity_decl_handler (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser, $handler): bool {}
 
 /**
  * Set up notation declaration handler
  * @link https://php.net/manual/en/function.xml-set-notation-decl-handler.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser to set up notation declaration handler function.
  * </p>
  * @param callable $handler <p>
@@ -211,15 +218,16 @@ function xml_set_unparsed_entity_decl_handler ($parser, callable $handler) {}
  * <b>string<i>public_id</i></b>
  * <i>parser</i>
  * The first parameter, parser, is a
- * reference to the XML parser calling the handler.
+ * reference to the XML parser calling the handler.</p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function xml_set_notation_decl_handler ($parser, callable $handler) {}
+function xml_set_notation_decl_handler (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser, $handler): bool
+{}
 
 /**
  * Set up external entity reference handler
  * @link https://php.net/manual/en/function.xml-set-external-entity-ref-handler.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser to set up external entity reference handler function.
  * </p>
  * @param callable $handler <p>
@@ -242,15 +250,16 @@ function xml_set_notation_decl_handler ($parser, callable $handler) {}
  * <b>string<i>public_id</i></b>
  * <i>parser</i>
  * The first parameter, parser, is a
- * reference to the XML parser calling the handler.
+ * reference to the XML parser calling the handler.</p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function xml_set_external_entity_ref_handler ($parser, callable $handler) {}
+function xml_set_external_entity_ref_handler (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser, $handler): bool
+{}
 
 /**
  * Set up start namespace declaration handler
  * @link https://php.net/manual/en/function.xml-set-start-namespace-decl-handler.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser.
  * </p>
  * @param callable $handler <p>
@@ -271,15 +280,16 @@ function xml_set_external_entity_ref_handler ($parser, callable $handler) {}
  * <b>string<i>uri</i></b>
  * <i>parser</i>
  * The first parameter, parser, is a
- * reference to the XML parser calling the handler.
+ * reference to the XML parser calling the handler.</p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function xml_set_start_namespace_decl_handler ($parser, callable $handler) {}
+function xml_set_start_namespace_decl_handler (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser, $handler): bool
+{}
 
 /**
  * Set up end namespace declaration handler
  * @link https://php.net/manual/en/function.xml-set-end-namespace-decl-handler.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser.
  * </p>
  * @param callable $handler <p>
@@ -299,15 +309,16 @@ function xml_set_start_namespace_decl_handler ($parser, callable $handler) {}
  * <b>string<i>prefix</i></b>
  * <i>parser</i>
  * The first parameter, parser, is a
- * reference to the XML parser calling the handler.
+ * reference to the XML parser calling the handler.</p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function xml_set_end_namespace_decl_handler ($parser, callable $handler) {}
+function xml_set_end_namespace_decl_handler (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser, $handler): bool
+{}
 
 /**
  * Start parsing an XML document
  * @link https://php.net/manual/en/function.xml-parse.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser to use.
  * </p>
  * @param string $data <p>
@@ -321,7 +332,6 @@ function xml_set_end_namespace_decl_handler ($parser, callable $handler) {}
  * data sent in this parse.
  * </p>
  * @return int 1 on success or 0 on failure.
- * </p>
  * <p>
  * For unsuccessful parses, error information can be retrieved with
  * <b>xml_get_error_code</b>,
@@ -333,70 +343,78 @@ function xml_set_end_namespace_decl_handler ($parser, callable $handler) {}
  * <p>
  * Entity errors are reported at the end of the data thus only if
  * <i>is_final</i> is set and <b>TRUE</b>.
+ * </p>
  */
-function xml_parse ($parser, $data, $is_final = false) {}
+function xml_parse (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser, string $data, bool $is_final = false): int
+{}
 
 /**
  * Parse XML data into an array structure
  * @link https://php.net/manual/en/function.xml-parse-into-struct.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser.
  * </p>
  * @param string $data <p>
  * A string containing the XML data.
  * </p>
- * @param array $values <p>
+ * @param array &$values <p>
  * An array containing the values of the XML data
  * </p>
- * @param array $index [optional] <p>
+ * @param array &$index [optional] <p>
  * An array containing pointers to the location of the appropriate values in the $values.
  * </p>
  * @return int <b>xml_parse_into_struct</b> returns 0 for failure and 1 for
  * success. This is not the same as <b>FALSE</b> and <b>TRUE</b>, be careful with
  * operators such as ===.
  */
-function xml_parse_into_struct ($parser, $data, array &$values, array &$index = null) {}
+function xml_parse_into_struct (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser, string $data, &$values, &$index): int
+{}
 
 /**
  * Get XML parser error code
  * @link https://php.net/manual/en/function.xml-get-error-code.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser to get error code from.
  * </p>
- * @return int|false This function returns <b>FALSE</b> if <i>parser</i> does
- * not refer to a valid parser, or else it returns one of the error
- * codes listed in the error codes
+ * @return int|false Returns one of the error codes listed in the error codes
  * section.
  */
-function xml_get_error_code ($parser) {}
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "int"], default: "int|false")]
+function xml_get_error_code (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser) {}
 
 /**
  * Get XML parser error string
  * @link https://php.net/manual/en/function.xml-error-string.php
- * @param int $code <p>
+ * @param int $error_code <p>
  * An error code from <b>xml_get_error_code</b>.
  * </p>
- * @return string a string with a textual description of the error
+ * @return string|null a string with a textual description of the error
  * <i>code</i>, or <b>FALSE</b> if no description was found.
  */
-function xml_error_string ($code) {}
+#[Pure]
+function xml_error_string (int $error_code): ?string
+{}
 
 /**
  * Get current line number for an XML parser
  * @link https://php.net/manual/en/function.xml-get-current-line-number.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser to get line number from.
  * </p>
  * @return int|false This function returns <b>FALSE</b> if <i>parser</i> does
  * not refer to a valid parser, or else it returns which line the
  * parser is currently at in its data buffer.
  */
-function xml_get_current_line_number ($parser) {}
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "int"], default: "int|false")]
+function xml_get_current_line_number (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser)
+{}
 
 /**
  * Get current column number for an XML parser
  * @link https://php.net/manual/en/function.xml-get-current-column-number.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser to get column number from.
  * </p>
  * @return int|false This function returns <b>FALSE</b> if <i>parser</i> does
@@ -405,33 +423,40 @@ function xml_get_current_line_number ($parser) {}
  * <b>xml_get_current_line_number</b>) the parser is
  * currently at.
  */
-function xml_get_current_column_number ($parser) {}
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "int"], default: "int|false")]
+function xml_get_current_column_number (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser)
+{}
 
 /**
  * Get current byte index for an XML parser
  * @link https://php.net/manual/en/function.xml-get-current-byte-index.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser to get byte index from.
  * </p>
  * @return int|false This function returns <b>FALSE</b> if <i>parser</i> does
  * not refer to a valid parser, or else it returns which byte index
  * the parser is currently at in its data buffer (starting at 0).
  */
-function xml_get_current_byte_index ($parser) {}
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "int"], default: "int|false")]
+function xml_get_current_byte_index (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser)
+{}
 
 /**
  * Free an XML parser
  * @link https://php.net/manual/en/function.xml-parser-free.php
- * @param resource $parser A reference to the XML parser to free.
+ * @param XMLParser|resource $parser A reference to the XML parser to free.
  * @return bool This function returns <b>FALSE</b> if <i>parser</i> does not
  * refer to a valid parser, or else it frees the parser and returns <b>TRUE</b>.
  */
-function xml_parser_free ($parser) {}
+function xml_parser_free (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser): bool
+{}
 
 /**
  * Set options in an XML parser
  * @link https://php.net/manual/en/function.xml-parser-set-option.php
- * @param resource $parser <p>
+ * @param XMLParser|resource $parser <p>
  * A reference to the XML parser to set an option in.
  * </p>
  * @param int $option <p>
@@ -489,21 +514,24 @@ function xml_parser_free ($parser) {}
  * refer to a valid parser, or if the option could not be set. Else the
  * option is set and <b>TRUE</b> is returned.
  */
-function xml_parser_set_option ($parser, $option, $value) {}
+function xml_parser_set_option (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser, int $option, $value): bool
+{}
 
 /**
  * Get options from an XML parser
  * @link https://php.net/manual/en/function.xml-parser-get-option.php
- * @param resource $parser A reference to the XML parser to get an option from.
+ * @param XMLParser|resource $parser A reference to the XML parser to get an option from.
  * @param int $option Which option to fetch. <b>XML_OPTION_CASE_FOLDING</b>
  * and <b>XML_OPTION_TARGET_ENCODING</b> are available.
  * See <b>xml_parser_set_option</b> for their description.
- * @return mixed This function returns <b>FALSE</b> if <i>parser</i> does
+ * @return string|int This function returns <b>FALSE</b> if <i>parser</i> does
  * not refer to a valid parser or if <i>option</i> isn't
  * valid (generates also a <b>E_WARNING</b>).
  * Else the option's value is returned.
  */
-function xml_parser_get_option ($parser, $option) {}
+#[Pure]
+function xml_parser_get_option (#[LanguageLevelTypeAware(["8.0" => "XMLParser"], default: "resource")] $parser, int $option): string|int
+{}
 
 define ('XML_ERROR_NONE', 0);
 define ('XML_ERROR_NO_MEMORY', 1);
@@ -539,5 +567,7 @@ define ('XML_OPTION_SKIP_WHITE', 4);
  */
 define ('XML_SAX_IMPL', "libxml");
 
+class XMLParser{}
+
 // End of xml v.
 ?>
