@@ -1,6 +1,9 @@
 <?php
 
 // Start of zlib v.2.0
+use JetBrains\PhpStorm\Deprecated;
+use JetBrains\PhpStorm\Internal\LanguageLevelTypeAware;
+use JetBrains\PhpStorm\Pure;
 
 /**
  * Output a gz-file
@@ -15,57 +18,59 @@
  * </p>
  * @return int|false the number of (uncompressed) bytes read from the file, or FALSE on error
  */
-function readgzfile ($filename, $use_include_path = 0) {}
+function readgzfile (string $filename, int $use_include_path = 0): int|false {}
 
 /**
  * Rewind the position of a gz-file pointer
  * @link https://php.net/manual/en/function.gzrewind.php
- * @param resource $zp <p>
+ * @param resource $stream <p>
  * The gz-file pointer. It must be valid, and must point to a file
  * successfully opened by <b>gzopen</b>.
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function gzrewind ($zp) {}
+function gzrewind ($stream): bool
+{}
 
 /**
  * Close an open gz-file pointer
  * @link https://php.net/manual/en/function.gzclose.php
- * @param resource $zp <p>
+ * @param resource $stream <p>
  * The gz-file pointer. It must be valid, and must point to a file
  * successfully opened by <b>gzopen</b>.
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function gzclose ($zp) {}
+function gzclose ($stream): bool
+{}
 
 /**
  * Test for EOF on a gz-file pointer
  * @link https://php.net/manual/en/function.gzeof.php
- * @param resource $zp <p>
+ * @param resource $stream <p>
  * The gz-file pointer. It must be valid, and must point to a file
  * successfully opened by <b>gzopen</b>.
  * </p>
- * @return int|bool <b>TRUE</b> if the gz-file pointer is at EOF or an error occurs;
+ * @return bool <b>TRUE</b> if the gz-file pointer is at EOF or an error occurs;
  * otherwise returns <b>FALSE</b>.
  */
-function gzeof ($zp) {}
+function gzeof ($stream): bool {}
 
 /**
  * Get character from gz-file pointer
  * @link https://php.net/manual/en/function.gzgetc.php
- * @param resource $zp <p>
+ * @param resource $stream <p>
  * The gz-file pointer. It must be valid, and must point to a file
  * successfully opened by <b>gzopen</b>.
  * </p>
  * @return string|false The uncompressed character or <b>FALSE</b> on EOF (unlike <b>gzeof</b>).
  */
-function gzgetc ($zp) {}
+function gzgetc ($stream): string|false {}
 
 /**
  * Get line from file pointer
  * @link https://php.net/manual/en/function.gzgets.php
- * @param resource $zp <p>
+ * @param resource $stream <p>
  * The gz-file pointer. It must be valid, and must point to a file
  * successfully opened by <b>gzopen</b>.
  * </p>
@@ -74,7 +79,7 @@ function gzgetc ($zp) {}
  * </p>
  * @return string|false The uncompressed string, or <b>FALSE</b> on error.
  */
-function gzgets ($zp, $length) {}
+function gzgets ($stream, int $length): string|false {}
 
 /**
  * Get line from gz-file pointer and strip HTML tags
@@ -91,24 +96,25 @@ function gzgets ($zp, $length) {}
  * be stripped.
  * </p>
  * @return string|false The uncompressed and striped string, or <b>FALSE</b> on error.
- * @deprecated 7.3
  * @removed 8.0
  */
-function gzgetss ($zp, $length, $allowable_tags = null) {}
+#[Deprecated(since: "7.3")]
+function gzgetss ($zp, int $length, $allowable_tags)
+{}
 
 /**
  * Binary-safe gz-file read
  * @link https://php.net/manual/en/function.gzread.php
- * @param resource $zp <p>
+ * @param resource $stream <p>
  * The gz-file pointer. It must be valid, and must point to a file
  * successfully opened by <b>gzopen</b>.
  * </p>
  * @param int $length <p>
  * The number of bytes to read.
  * </p>
- * @return string The data that have been read.
+ * @return string|false The data that have been read.
  */
-function gzread ($zp, $length) {}
+function gzread ($stream, int $length): string|false {}
 
 /**
  * Open gz-file
@@ -137,24 +143,25 @@ function gzread ($zp, $length) {}
  * <p>
  * If the open fails, the function returns <b>FALSE</b>.
  */
-function gzopen ($filename, $mode, $use_include_path = 0) {}
+function gzopen (string $filename, string $mode, int $use_include_path = 0) {}
 
 /**
  * Output all remaining data on a gz-file pointer
  * @link https://php.net/manual/en/function.gzpassthru.php
- * @param resource $zp <p>
+ * @param resource $stream <p>
  * The gz-file pointer. It must be valid, and must point to a file
  * successfully opened by <b>gzopen</b>.
  * </p>
  * @return int The number of uncompressed characters read from <i>gz</i>
  * and passed through to the input, or <b>FALSE</b> on error.
  */
-function gzpassthru ($zp) {}
+function gzpassthru ($stream): int
+{}
 
 /**
  * Seek on a gz-file pointer
  * @link https://php.net/manual/en/function.gzseek.php
- * @param resource $zp <p>
+ * @param resource $stream <p>
  * The gz-file pointer. It must be valid, and must point to a file
  * successfully opened by <b>gzopen</b>.
  * </p>
@@ -173,30 +180,31 @@ function gzpassthru ($zp) {}
  * @return int Upon success, returns 0; otherwise, returns -1. Note that seeking
  * past EOF is not considered an error.
  */
-function gzseek ($zp, $offset, $whence = SEEK_SET) {}
+function gzseek ($stream, int $offset, int $whence = SEEK_SET): int
+{}
 
 /**
  * Tell gz-file pointer read/write position
  * @link https://php.net/manual/en/function.gztell.php
- * @param resource $zp <p>
+ * @param resource $stream <p>
  * The gz-file pointer. It must be valid, and must point to a file
  * successfully opened by <b>gzopen</b>.
  * </p>
  * @return int|false The position of the file pointer or <b>FALSE</b> if an error occurs.
  */
-function gztell ($zp) {}
+function gztell ($stream): int|false {}
 
 /**
  * Binary-safe gz-file write
  * @link https://php.net/manual/en/function.gzwrite.php
- * @param resource $zp <p>
+ * @param resource $stream <p>
  * The gz-file pointer. It must be valid, and must point to a file
  * successfully opened by <b>gzopen</b>.
  * </p>
- * @param string $string <p>
+ * @param string $data <p>
  * The string to write.
  * </p>
- * @param int $length [optional] <p>
+ * @param int|null $length [optional] <p>
  * The number of uncompressed bytes to write. If supplied, writing will
  * stop after <i>length</i> (uncompressed) bytes have been
  * written or the end of <i>string</i> is reached,
@@ -208,19 +216,21 @@ function gztell ($zp) {}
  * configuration option will be ignored and no slashes will be
  * stripped from <i>string</i>.
  * </p>
- * @return int the number of (uncompressed) bytes written to the given gz-file
+ * @return int|false the number of (uncompressed) bytes written to the given gz-file
  * stream.
  */
-function gzwrite ($zp, $string, $length = null) {}
+function gzwrite ($stream, string $data, ?int $length): int|false
+{}
 
 /**
  * Alias of <b>gzwrite</b>
  * @link https://php.net/manual/en/function.gzputs.php
- * @param resource $fp
- * @param string $str
- * @param int $length [optional]
+ * @param resource $stream
+ * @param string $data
+ * @param int|null $length [optional]
+ * @return int|false
  */
-function gzputs ($fp, $str, $length) {}
+function gzputs ($stream, string $data, ?int $length): int|false {}
 
 /**
  * Read entire gz-file into an array
@@ -232,9 +242,9 @@ function gzputs ($fp, $str, $length) {}
  * You can set this optional parameter to 1, if you
  * want to search for the file in the include_path too.
  * </p>
- * @return array An array containing the file, one line per cell.
+ * @return array|false An array containing the file, one line per cell.
  */
-function gzfile ($filename, $use_include_path = 0) {}
+function gzfile (string $filename, int $use_include_path = 0): array|false {}
 
 /**
  * Compress a string
@@ -254,7 +264,8 @@ function gzfile ($filename, $use_include_path = 0) {}
  * </p>
  * @return string|false The compressed string or <b>FALSE</b> if an error occurred.
  */
-function gzcompress ($data, $level = -1, $encoding = ZLIB_ENCODING_DEFLATE) {}
+#[Pure]
+function gzcompress (string $data, int $level = -1, int $encoding = ZLIB_ENCODING_DEFLATE): string|false {}
 
 /**
  * Uncompress a compressed string
@@ -262,17 +273,18 @@ function gzcompress ($data, $level = -1, $encoding = ZLIB_ENCODING_DEFLATE) {}
  * @param string $data <p>
  * The data compressed by <b>gzcompress</b>.
  * </p>
- * @param int $length [optional] <p>
+ * @param int $max_length [optional] <p>
  * The maximum length of data to decode.
  * </p>
  * @return string|false The original uncompressed data or <b>FALSE</b> on error.
- * </p>
  * <p>
  * The function will return an error if the uncompressed data is more than
  * 32768 times the length of the compressed input <i>data</i>
  * or more than the optional parameter <i>length</i>.
+ * </p>
  */
-function gzuncompress ($data, $length = 0) {}
+#[Pure]
+function gzuncompress (string $data, int $max_length = 0): string|false {}
 
 /**
  * Deflate a string
@@ -290,7 +302,8 @@ function gzuncompress ($data, $length = 0) {}
  * </p>
  * @return string|false The deflated string or <b>FALSE</b> if an error occurred.
  */
-function gzdeflate ($data, $level = -1, $encoding = ZLIB_ENCODING_RAW) {}
+#[Pure]
+function gzdeflate (string $data, int $level = -1, int $encoding = ZLIB_ENCODING_RAW): string|false {}
 
 /**
  * Inflate a deflated string
@@ -298,17 +311,18 @@ function gzdeflate ($data, $level = -1, $encoding = ZLIB_ENCODING_RAW) {}
  * @param string $data <p>
  * The data compressed by <b>gzdeflate</b>.
  * </p>
- * @param int $length [optional] <p>
+ * @param int $max_length [optional] <p>
  * The maximum length of data to decode.
  * </p>
  * @return string|false The original uncompressed data or <b>FALSE</b> on error.
- * </p>
  * <p>
  * The function will return an error if the uncompressed data is more than
  * 32768 times the length of the compressed input <i>data</i>
  * or more than the optional parameter <i>length</i>.
+ * </p>
  */
-function gzinflate ($data, $length = 0) {}
+#[Pure]
+function gzinflate (string $data, int $max_length = 0): string|false {}
 
 /**
  * Create a gzip compressed string
@@ -321,7 +335,7 @@ function gzinflate ($data, $length = 0) {}
  * for maximum compression. If not given, the default compression level will
  * be the default compression level of the zlib library.
  * </p>
- * @param int $encoding_mode [optional] <p>
+ * @param int $encoding [optional] <p>
  * The encoding mode. Can be <b>FORCE_GZIP</b> (the default)
  * or <b>FORCE_DEFLATE</b>.
  * </p>
@@ -337,7 +351,8 @@ function gzinflate ($data, $length = 0) {}
  * </p>
  * @return string|false The encoded string, or <b>FALSE</b> if an error occurred.
  */
-function gzencode ($data, $level = -1, $encoding_mode = FORCE_GZIP) {}
+#[Pure]
+function gzencode (string $data, int $level = -1, int $encoding = FORCE_GZIP): string|false {}
 
 /**
  * Decodes a gzip compressed string
@@ -345,56 +360,62 @@ function gzencode ($data, $level = -1, $encoding_mode = FORCE_GZIP) {}
  * @param string $data <p>
  * The data to decode, encoded by <b>gzencode</b>.
  * </p>
- * @param int $length [optional] <p>
+ * @param int $max_length [optional] <p>
  * The maximum length of data to decode.
  * </p>
  * @return string|false The decoded string, or <b>FALSE</b> if an error occurred.
  * @since 5.4
  */
-function gzdecode ($data, $length = null) {}
+#[Pure]
+function gzdecode (string $data, int $max_length): string|false
+{}
 
 /**
  * Compress data with the specified encoding
  * @link https://php.net/manual/en/function.zlib-encode.php
  * @param string $data <p>
  * </p>
- * @param string $encoding <p>
+ * @param int $encoding <p>
  * </p>
- * @param string $level [optional] default -1 <p>
+ * @param int $level [optional] default -1 <p>
  * </p>
- * @return string
+ * @return string|false
  * @since 5.4
  */
-function zlib_encode ($data, $encoding, $level) {}
+#[Pure]
+function zlib_encode (string $data, int $encoding, int $level): string|false {}
 
 /**
  * Uncompress any raw/gzip/zlib encoded data
  * @link https://php.net/manual/en/function.zlib-decode.php
  * @param string $data <p>
  * </p>
- * @param string $max_decoded_len [optional] <p>
+ * @param int $max_length [optional] <p>
  * </p>
- * @return string
+ * @return string|false
  * @since 5.4
  */
-function zlib_decode ($data, $max_decoded_len = null) {}
+#[Pure]
+function zlib_decode (string $data, int $max_length): string|false
+{}
 
 /**
  * Returns the coding type used for output compression
  * @link https://php.net/manual/en/function.zlib-get-coding-type.php
- * @return string Possible return values are gzip, deflate,
+ * @return string|false Possible return values are gzip, deflate,
  * or <b>FALSE</b>.
  */
-function zlib_get_coding_type () {}
+#[Pure]
+function zlib_get_coding_type (): string|false {}
 
 /**
  * ob_start callback function to gzip output buffer
  * @link https://php.net/manual/en/function.ob-gzhandler.php
- * @param string $buffer
- * @param int $mode
- * @return string
+ * @param string $data
+ * @param int $flags
+ * @return string|false
  */
-function ob_gzhandler ($buffer, $mode) {}
+function ob_gzhandler (string $data, int $flags): string|false {}
 
 /**
  * Initialize an incremental deflate context
@@ -417,12 +438,14 @@ function ob_gzhandler ($buffer, $mode) {}
  * </p>
  * @since 7.0
  */
-function deflate_init ($encoding, $options = array()) {}
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "DeflateContext|false"], default: "resource|false")]
+function deflate_init (int $encoding, array $options = array()) {}
 
 /**
  * Incrementally deflate data
  * @link https://php.net/manual/en/function.deflate-add.php
- * @param resource $context <p>
+ * @param DeflateContext|resource $context <p>
  * A context created with <b>deflate_init()</b>.
  * </p>
  * @param string $data <p>
@@ -440,7 +463,7 @@ function deflate_init ($encoding, $options = array()) {}
  * </p>
  * @since 7.0
  */
-function deflate_add ($context, $data, $flush_mode = ZLIB_SYNC_FLUSH) {}
+function deflate_add (#[LanguageLevelTypeAware(["8.0" => "DeflateContext"], default: "resource")] $context, string $data, int $flush_mode = ZLIB_SYNC_FLUSH): string|false {}
 
 /**
  * Initialize an incremental inflate context
@@ -463,15 +486,17 @@ function deflate_add ($context, $data, $flush_mode = ZLIB_SYNC_FLUSH) {}
  * </p>
  * @since 7.0
  */
-function inflate_init ($encoding, $options = array()) {}
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "InflateContext|false"], default: "resource|false")]
+function inflate_init (int $encoding, array $options = array()) {}
 
 /**
- * Incrementally inflate data
+ * Incrementally inflate encoded data
  * @link https://php.net/manual/en/function.inflate-add.php
- * @param resource $context <p>
+ * @param InflateContext|resource $context <p>
  * A context created with <b>inflate_init()</b>.
  * </p>
- * @param string $encoded_data <p>
+ * @param string $data <p>
  * A chunk of compressed data.
  * </p>
  * @param int $flush_mode [optional] <p>
@@ -486,31 +511,47 @@ function inflate_init ($encoding, $options = array()) {}
  * </p>
  * @since 7.0
  */
-function inflate_add ($context, $encoded_data, $flush_mode = ZLIB_SYNC_FLUSH) {}
+function inflate_add (#[LanguageLevelTypeAware(["8.0" => "InflateContext"], default: "resource")] $context, string $data, int $flush_mode = ZLIB_SYNC_FLUSH): string|false {}
 
 /**
- * @param resource $context
- * @return bool
+ * Get number of bytes read so far
+ * @param InflateContext|resource $context
+ * @return int
  * @since 7.2
  */
-function inflate_get_read_len ($context){}
+#[Pure]
+function inflate_get_read_len (#[LanguageLevelTypeAware(["8.0" => "InflateContext"], default: "resource")] $context): int{}
 
 /**
- * @param resource $context
- * @return bool
+ * Get decompression status
+ * @param InflateContext|resource $context
+ * @return int
  * @since 7.2
  */
-function  inflate_get_status($context) {}
+#[Pure]
+function  inflate_get_status(#[LanguageLevelTypeAware(["8.0" => "InflateContext"], default: "resource")] $context): int {}
 
 /**
  * @since 8.0
  */
-class InflateContext{}
+class InflateContext{
+    /**
+     * Use inflate_init() instead
+     * @see inflate_init()
+     */
+    private function __construct(){}
+}
 
 /**
  * @since 8.0
  */
-class DeflateContext{}
+class DeflateContext{
+    /**
+     * Use deflate_init() instead
+     * @see deflate_init()
+     */
+    private function __construct(){}
+}
 
 define ('FORCE_GZIP', 31);
 define ('FORCE_DEFLATE', 15);
